pkg.env <- new.env()

pkg.env$mcqr_separator_string <- "+--+"

setClass(
		"mcqMetadata",
		slots = list(metadata="data.frame",samples="data.frame"),
		validity=function(object){
			cat("Checking mcqMetadata validity\n")
			if ('msrunfile' %in% colnames(object@metadata)) {
				cat ("mcqMetadata shouldn't have an msrunfile column\n")
				return(FALSE)
			}
			if ('msrun' %in% colnames(object@metadata)) {
				cat ("mcqMetadata shouldn't have an msrun column\n")
				return(FALSE)
			}
			cat("mcqMetadata object is valid\n")
			return(TRUE)
		}
)


setClass(
		"mcqData",
		slots = list(quantipeptides="data.frame",samples="list", groups="list",
				proteins="list",peptidesmh="data.frame", observedin="data.frame",quantify="matrix"),
		validity=function(object){
			cat("Validity\n")
			return(TRUE)
		}
)


setClass(
		"mcq.protlist",
		#very simple structure : proteins is a list with named elements
		# the names are the protein accessions
		# the elements are the protein description
		slots = list(proteins="character"),
		validity=function(object){
			cat("Checking validity\n")

			cat("mcqProtList object is valid\n")
			return(TRUE)
		}
)


setClass(
		"mcqProtPep",
		slots = list(proteins="data.frame",peptides="data.frame", metadata="mcqMetadata", nona="data.frame"),
		validity=function(object){
			return(priv.check.protpep(object))
		}
)

setClass(
		"mcq.skyline",
		slots = list(proteins="data.frame",peptides="data.frame", metadata="mcqMetadata", nona="data.frame"),
		validity=function(object){
			return(priv.check.protpep(object))
		}
)

setClass(
		"mcq.class.peptide.pca",
		slots = list(tag="data.frame", metadata="mcqMetadata",samples="data.frame",pca="list"),
		validity=function(object){
			cat("Checking validity\n")
			cat("mcq.class.peptide.pca object is valid\n")
			return(TRUE)
		}
)

setClass(
		"mcq.class.prot.pca",
		slots = list(tag="data.frame", metadata="mcqMetadata",samples="data.frame",pca="list"),
		validity=function(object){
			cat("Checking validity\n")
			cat("mcq.class.prot.pca object is valid\n")
			return(TRUE)
		}
)

setClass(
		"mcq.protquantity",
		slots = list(proteins="data.frame",metadata="mcqMetadata",protval="data.frame",samples="data.frame"),
		validity=function(object){
			return(priv.check.protq(object))
		}
)

setClass(
		"mcq.spectralcounting",
		slots = list(proteins="data.frame",metadata="mcqMetadata",protval="data.frame",samples="data.frame"),
		validity=function(object){
			return(priv.check.protq(object))
		}
)

setClass(
		"mcq.peakcounting",
		slots = list(proteins="data.frame",metadata="mcqMetadata",protval="data.frame",samples="data.frame"),
		validity=function(object){
			return(priv.check.protq(object))
		}
)

setClass(
		"mcq.protquantity.anova",
		slots = list(proteins="data.frame",metadata="mcqMetadata",samples="data.frame", paramlist = "list", protval="data.frame", resultanov="data.frame", resulttukey="list"),
		validity=function(object){
			cat("Checking validity\n")

			cat("mcq.prot.anova object is valid\n")
			return(TRUE)
		}
)

setClass(
		"mcq.spectralcounting.anova",
		slots = list(proteins="data.frame",metadata="mcqMetadata",samples="data.frame", paramlist = "list", protval="data.frame", resultanov="data.frame", resulttukey="list"),
		validity=function(object){
			cat("Checking validity\n")

			cat("mcq.spectralcounting.anova object is valid\n")
			return(TRUE)
		}
)


setClass(
		"mcq.peakcounting.anova",
		slots = list(proteins="data.frame",metadata="mcqMetadata",samples="data.frame", paramlist = "list", protval="data.frame", resultanov="data.frame", resulttukey="list"),
		validity=function(object){
			cat("Checking validity\n")

			cat("mcq.peakcounting.anova object is valid\n")
			return(TRUE)
		}
)


setClass(
		"mcq.pairwise.t.test",
		slots = list(proteins="data.frame",metadata="mcqMetadata",samples="data.frame", paramlist = "list", protval="data.frame", restest = "list"),
		validity=function(object){
			cat("Checking validity\n")

			cat("mcq.pairwise.t.test object is valid\n")
			return(TRUE)
		}
)


setClass(
		"mcq.peakcounting.glm",
		slots = list(proteins="data.frame",metadata="mcqMetadata",samples="data.frame", paramlist = "list", protval="data.frame", resultglm="data.frame"),
		validity=function(object){
			cat("Checking validity\n")

			cat("mcq.peakcounting.glm object is valid\n")
			return(TRUE)
		}
)


