
mcq.get.protlist <- function(object, fdr=NULL, pair=NULL) {
	if ((class(object) == "mcqProtPep") || (class(object) == "mcq.skyline")) {
		df <- unique(object@proteins[,c("accession","protein_description")])
		proteinvector <- as.character(df$protein_description)
		names(proteinvector) <- as.character(df$accession)

		newObject <- new ("mcq.protlist", proteins = proteinvector)
		return (newObject)
	} else if (priv.mcq.is.anova.object(object) || priv.mcq.is.protquant.object(object)) {
		proteinvector <- as.character(object@proteins$descr)
		names(proteinvector) <- as.character(object@proteins$accession)

		newObject <- new ("mcq.protlist", proteins = proteinvector)
		return (newObject)
	} else if (class(object) == "mcq.pairwise.t.test") {
		if (!is.null(pair)) {
			if (is.vector(pair) && (length(pair) == 2)) {
				#pairstr <- paste(pair, collapse="--")
				pairstr <- paste(pair, collapse=pkg.env$mcqr_separator_string)
				#warning(pairstr)
				tabprot <- object@restest$pair.result[object@restest$pair.result$pairs == pairstr,]
				if (nrow(tabprot) == 0) {
					#pairstr <- paste(pair[2], pair[1], sep="--")
					pairstr <- paste(pair[2], pair[1], sep=pkg.env$mcqr_separator_string)
					tabprot <- object@restest$pair.result[object@restest$pair.result$pairs == pairstr,]
				}
				if (nrow(tabprot) == 0) {
					stop(paste("There is no pair defined for the 2 sample names", paste(pair,collapse=" "), ": please check your sample names.",sep=" "))
				}
			}
			else {
				stop(paste("the pair argument must be vector containing 2 sample names",sep=""))
			}
		}
		else {
			tabprot <- object@restest$pair.result
		}
		#object@pair.result$proteins padjust
		tabprot <- merge (tabprot, object@proteins, by.x="proteins", by.y="row.names")

		#print (head(tabprot))

		if (is.null(fdr)) {
		} else {
			tabprot <- tabprot[tabprot$padjust <= fdr ,]
		}
		#print (head(tabprot))
		tabprot <- unique(tabprot[,c("accession", "descr")])
		proteinvector <- tabprot$descr
		names(proteinvector) <- tabprot$accession

		newObject <- new ("mcq.protlist", proteins = proteinvector)
		return (newObject)
	} else if (class(object) == "character") {
		proteinvector <- object
		names(proteinvector) <- object

		newObject <- new ("mcq.protlist", proteins = proteinvector)
		return (newObject)
	}
	else {
		stop(paste("the class \"", class(object),"\" is not taken into account by mcq.get.protlist",sep=""))
	}
}

