
mcq.normalize<- function (object, refSample=NULL, method="median") {
	if ((class(object) == "mcqProtPep") || (class(object) == "mcq.skyline")) {
		cat(paste("normalizing samples using the ",method," method\n",sep=""))
		if (method == "percent") {
			fact=aggregate(object@peptides$area,list(object@peptides$msrun), FUN=sum)
			colnames(fact)=c("msrun","somme")
			fact$moy=mean(fact$somme)
			fact$fact=fact$moy/fact$somme
			fact$somme=NULL
			fact$moy=NULL
			object@peptides=merge(object@peptides, fact, by.x="msrun", by.y="msrun")

			object@peptides$areanorm=object@peptides$area*object@peptides$fact
			object@peptides$fact <- NULL
			object@peptides$lognorm=log10(object@peptides$areanorm)
		}

		if (method == "median" | method == "median.RT") {
			if (!is.null(refSample)){
				if (!refSample %in% object@peptides$msrun) {
					stop(paste("the sample named ",refSample," is not in your \"", class(object),"\" object\n", sep=""))
				}
			}else{ #by default, the sample with the highest nb of peaks is taken as ref sample
				count=table(protPep@peptides$msrun) 
				refSample=names(count[count==max(count)])[1]
			}

			mat.obj<- tapply (object@peptides$logarea, list(object@peptides$peptiz,object@peptides$msrun), FUN=sum)
			ref=which(colnames(mat.obj)==refSample) 
			nbech=dim(mat.obj)[2] 
			nbpep=dim(mat.obj)[1] 
			mat.ref=matrix(rep(mat.obj[,ref],nbech),ncol=nbech)
			diff=mat.obj-mat.ref
 
			if (method == "median"){
				diffmed=apply(diff,2,median,na.rm=TRUE)
				diffmed=as.data.frame(diffmed)
		
				object@peptides=merge(object@peptides, diffmed, by.x="msrun", by.y="row.names")

				object@peptides$lognorm=object@peptides$logarea-object@peptides$diffmed
				object@peptides$areanorm=10^(object@peptides$lognorm)
			}
			if (method == "median.RT"){
				tab.diff=stack(as.data.frame(diff))
				tab.diff=cbind.data.frame(rep(rownames(mat.obj),nbech), tab.diff)
				colnames(tab.diff)=c("peptiz","diff","msrun")
				indice=match(paste(tab.diff$msrun, tab.diff$peptiz), paste(object@peptides$msrun, object@peptides$peptiz))
				tab.diff$rt=object@peptides$rt[indice]

				tab.diff=tab.diff[order(tab.diff$msrun, tab.diff$rt),]
				tab.diff=tab.diff[!is.na(tab.diff$rt),]
				tab.diff$correc=NA
				compteur=unique(tab.diff$msrun)

				for (i in 1:length(compteur)) {
				#calculation of the correction factor
					select.samp <- tab.diff$msrun==compteur[i]	
					select.na <- is.na(tab.diff$diff)
				
					cour <- tab.diff[select.samp,]
					cour.nomiss <- tab.diff[select.samp & !select.na,]

					yyy=smooth.spline(cour.nomiss$rt,cour.nomiss$diff,spar=0.5)
					indice=match(tab.diff$rt[select.samp & !select.na], yyy$x)
					tab.diff$correc[select.samp & !select.na] = yyy$y[indice]	

				#propagation to the peptide-charge that were absent in the reference
					smo=tab.diff$correc[select.samp] 
					j=1
					while(is.na(smo[j])) {smo[j]=0; j=j+1}
					while (j < length(smo)) {
						while(!is.na(smo)[j] & j<length(smo)) {last=smo[j]; j=j+1}
						while(is.na(smo[j]) & j<length(smo)) {smo[j]=last; j=j+1}
					}  
					smo[length(smo)]=smo[length(smo)-1] 
					tab.diff$correc[select.samp] =smo
					if (i%%2==0) cat(paste(i," samples\n"))
				}

				indice=match(paste(object@peptides$msrun, object@peptides$peptiz), paste(tab.diff$msrun, tab.diff$peptiz))
				object@peptides$correc=tab.diff$correc[indice]
				object@peptides$lognorm=object@peptides$logarea-object@peptides$correc
				object@peptides$areanorm=10^(object@peptides$lognorm)

			}
		}
		return (object)
	}
	else {
		stop(paste("the class \"", class(object),"\" is not taken into account by mcqNormalizeBySampleref",sep=""))
	}
}












