
mcq.plot.cluster= function (object, flist=NULL, nbclust=8, file=NULL, outputfile=NULL) {
	# check the validity of object and flist and nbclust
	if ((class(object) != "mcq.protquantity") && (class(object) != "mcq.spectralcounting") && (class(object) != "mcq.peakcounting") && (class(object) != "mcq.peakcounting.anova") && (class(object) != "mcq.protquantity.anova") && (class(object) != "mcq.spectralcounting.anova")) {
		stop(paste("the class ", class(object)," is not taken into account by mcq.plot.cluster",sep=""))

	}

	if (!is.null(flist)) {
		for (factor in flist) {
			if(!factor %in% names(object@metadata@metadata)) {
				stop(paste("factor ", factor, " is not described in your metadata\n", "available factors are : ", paste(colnames(object@metadata@metadata),collapse=", "), "\n", sep=""))
			}
		}
	}
	if (nbclust>=length(object@proteins$accession)||nbclust<2) {
		stop(paste("the nbclust integer must be included between 1 and ", length(object@proteins$accession), " the number of significant proteins, (so two proteins are not enough for clustering)" ,sep=""))
	}
	
	# create the data frame for clustering
	tprot <- merge(object@protval, object@metadata@metadata, by.x="msrun", by.y="row.names")
	tprot <- merge(tprot, object@samples, by.x="msrun", by.y="row.names")
	tprot <- merge(tprot, object@proteins, by.x="protein", by.y="row.names")

	if (is.null(flist)){
		tacp= tapply (tprot$q, list(tprot$accession,tprot$msrunfile), FUN=mean, na.rm=TRUE)
		dim1=nrow(tacp)
		tacp=na.omit(tacp)
		dim2=nrow(tacp)
		cex.x=0.7
	}else{
		if(length(flist)==1){
			tprot$echantillon=tprot[, flist]
			tacp= tapply (tprot$q, list(tprot$accession,tprot$echantillon), FUN=mean, na.rm=TRUE)
			dim1=nrow(tacp)
			tacp=na.omit(tacp)
			dim2=nrow(tacp)
			cex.x=1
		}
		if(length(flist)>1){
			tprot$echantillon=apply(tprot[,colnames(tprot) %in% flist], 1, paste, collapse="-")
			tacp= tapply (tprot$q, list(tprot$accession,tprot$echantillon), FUN=mean, na.rm=TRUE)
			dim1=nrow(tacp)
			tacp=na.omit(tacp)
			dim2=nrow(tacp)
			tacp=tacp[,order(colnames(tacp))]
			cex.x=1
		}
	}

	if (dim1!=dim2){
		warning(paste("Your dataset contains ", dim1-dim2, " out of ", dim1, " proteins that are completely missing in some samples or in some levels of your flist. These proteins are not represented in the clusters.", sep=""))
	}


	# clustering using the method SOTA (Self-Organizing Tree Algorithm)
	tacp.scale=t(scale(t(tacp))) 
	tacp.scale.nona=na.omit(tacp.scale)
	
	if (nrow(tacp.scale)!=nrow(tacp.scale.nona)){
		warning(paste("Your dataset contains " ,nrow(tacp.scale)-nrow(tacp.scale.nona)," out of ",nrow(tacp.scale)," proteins that are constant in all samples. These proteins are not represented in the clusters.", sep=""))
	}
	
	cl.sota <- sota(tacp.scale.nona, nbclust-1)
	tacp.clust=data.frame(tacp.scale.nona,cl.sota=cl.sota$clust)

	if (is.null(file)){
		par(ask=TRUE)
		for (i in 1:nbclust) {
			par(mar=c(10,4,4,2))
			cl=tacp.clust[tacp.clust$cl.sota==i,]
			cl$cl.sota=NULL
			matplot(t(cl),type="l",col="gray",lty=1,xaxt="none",ylab="Scaled protein abundance", main=paste("Cluster",i))
			axis(1,outer=FALSE,labels=colnames(tacp),cex.axis=cex.x,hadj=1,padj=0,las=2,at=1:length(colnames(tacp)))
			mtext(paste("Nb of proteins:",cl.sota$totals[i]),side=3,line=1,adj=0)
			mmm=apply(cl,2,FUN=mean)
			matlines(mmm,col="red")
		}
	}else{
		pdf(file, title=gsub('.pdf$','',file), width=17, height=12)
		par(mfrow=c(2,3))
		for (i in 1:nbclust) {
			par(pin=c(4,2.5))
			cl=tacp.clust[tacp.clust$cl.sota==i,]
			cl$cl.sota=NULL
			matplot(t(cl),type="l",col="gray",lty=1,xaxt="none",ylab="Scaled protein abundance", main=paste("Cluster",i))
			axis(1,outer=FALSE,labels=colnames(tacp),cex.axis=cex.x,hadj=1,padj=0,las=2,at=1:length(colnames(tacp)))
			mtext(paste("Nb of proteins:",cl.sota$totals[i]),side=3,line=1,adj=0, cex=0.8)
			mmm=apply(cl,2,FUN=mean)
			matlines(mmm,col="red")
		}
	}

	if (!is.null(file)){
		dev.off()
	}
	par(mfrow=c(1,1))

	# export the outputfile
	if (!is.null(outputfile)){
		tacp.clust=merge(tacp.clust,qprot@proteins,by.x="row.names",by.y="accession")
		colnames(tacp.clust)[1]=""
		colnames(tacp.clust)[ncol(tacp.clust)]="protein_description"
		colnames(tacp.clust)[ncol(tacp.clust)-1]="cluster_number"
		write.table(tacp.clust, outputfile , quote= FALSE,  sep="\t", dec=".",row.names=F)
	}


}

