
mcq.plot.global.intensity <- function (object, factorToColor=NULL, file=NULL) {

  # control object
	if ((class(object) == "mcqProtPep") || (class(object) == "mcq.skyline")) {

	}else{
		stop(paste("The class \"", class(object),"\" is not taken into account by mcq.plot.intensity.distributions" ,sep=""))
	}

  # control parameters : factorToColor
	if (!is.null(factorToColor)) {
		if(length(factorToColor)>1){
			stop("Please choose only one factor for the 'factorToColor' argument")
		}
		if(!factorToColor %in% colnames(object@metadata@metadata)) {
			stop(paste("The factor ", factorToColor, " chosen for factorToColor is not described in your metadata\n", "please choose one in: ", paste(colnames(object@metadata@metadata),collapse=", "), "\n", sep=""))
		}
	}

	tab=merge(object@peptides, object@metadata@metadata, by.x="msrun", by.y="row.names")
	

	if (is.null(file)){
		par(ask=FALSE)
	}else{	
		pdf(file, title=gsub('.pdf$','',file), width=15)
	}

	if (is.null(object@peptides$lognorm)) {
		if(is.null(factorToColor)){
			 plot1 <- ggplot(tab, aes(factor(msrun), logarea)) + geom_violin(draw_quantiles = c(0.25, 0.5, 0.75), adjust=.8)+labs(title = "Violin plot of peptide intensities", y="Log-intensity", x="Sample")+theme(axis.text.x = element_text(angle=90))+guides(fill=guide_legend(title = ""))
			grid.arrange(plot1, nrow=1, ncol=1)
		}else{
			plot1 <- ggplot(tab, aes(factor(msrun), logarea)) + geom_violin(draw_quantiles = c(0.25, 0.5, 0.75), adjust=.8, aes(fill = tab[,factorToColor]))+labs(title = "Violin plot of peptide intensities", y="Log-intensity", x="Sample")+theme(axis.text.x = element_text(angle=90))+guides(fill=guide_legend(title = ""))
			grid.arrange(plot1, nrow=1, ncol=1)
		}

	}else{
		if(is.null(factorToColor)){
			plot1 <- ggplot(tab, aes(factor(msrun), logarea))+ geom_violin(draw_quantiles = c(0.25, 0.5, 0.75), adjust=.8)+labs(title = c("Log-intensities distributions before normalization"), y="Log-intensity", x="Sample")+theme(axis.text.x = element_text(angle=90)) +guides(fill=guide_legend(title = "")) +   theme(plot.title=element_text(size=10))
			plot2 <- ggplot(tab, aes(factor(msrun), lognorm)) + geom_violin(draw_quantiles = c(0.25, 0.5, 0.75), adjust=.8)+labs(title = c("Log-intensities distributions after normalization"), y="Log-intensity", x="Sample")+theme(axis.text.x = element_text(angle=90))+guides(fill=guide_legend(title = "")) +   theme(plot.title=element_text(size=10))
			grid.arrange(plot1, plot2, nrow=1, ncol=2)
		}else{
			plot1 <- ggplot(tab, aes(factor(msrun), logarea))+ geom_violin(draw_quantiles = c(0.25, 0.5, 0.75), adjust=.8, aes(fill = tab[,factorToColor]))+labs(title = c("Log-intensities distributions before normalization"), y="Log-intensity", x="Sample")+theme(axis.text.x = element_text(angle=90)) +guides(fill=guide_legend(title = "")) +   theme(plot.title=element_text(size=10))
			plot2 <- ggplot(tab, aes(factor(msrun), lognorm)) + geom_violin(draw_quantiles = c(0.25, 0.5, 0.75), adjust=.8, aes(fill = tab[,factorToColor]))+labs(title = c("Log-intensities distributions after normalization"), y="Log-intensity", x="Sample")+theme(axis.text.x = element_text(angle=90))+guides(fill=guide_legend(title = "")) +   theme(plot.title=element_text(size=10))
			grid.arrange(plot1, plot2, nrow=1, ncol=2)
		}
	}

	if (!is.null(file)){
		dev.off()
	}

}

