
mcq.plot.heatmap= function (object,flist=NULL, factorToColor=NULL, distfun=NULL, method="ave", file=NULL, cexCol=0.8, cexRow=0.2) {
	# check the validity of object and flist
	if ((class(object) != "mcq.protquantity") && (class(object) != "mcq.spectralcounting") && (class(object) != "mcq.peakcounting") && (class(object) != "mcq.peakcounting.anova") && (class(object) != "mcq.protquantity.anova") && (class(object) != "mcq.spectralcounting.anova")) {
		stop(paste("the class ", class(object)," is not taken into account by mcq.plot.heatmap",sep=""))
	}

	if (!is.null(flist)) {
		for (factor in flist) {
			if(!factor %in% names(object@metadata@metadata)) {
				stop(paste("factor ", factor, " is not described in your metadata\n", "available factors are : ", paste(colnames(object@metadata@metadata),collapse=", "), "\n", sep=""))
			}
		}
	}


	# check the validity of factorToColor
	if (!is.null(factorToColor)) {
		if((length(factorToColor) > length(flist)) & (length(flist)>0)){
			stop(paste("Too many factors chosen for factorToColor (", factorToColor, "), please choose one in: ", flist,"\n",sep=""))
		}

		if((length(factorToColor)>0) & (length(which(!factorToColor %in% flist))>0)){
			stop(paste("The factors chosen for factorToColor are not in agreement with those selected for flist."))
		}
		for (color in factorToColor){
			if(!color %in% colnames(object@metadata@metadata)) {
				stop(paste("The factor ", color, " chosen for factorToColor is not described in your metadata\n", "please choose one in: ", paste(colnames(object@metadata@metadata),collapse=", "), "\n", sep=""))
			}
		}
	}


	# create the data frame for heatmap
	tprot <- merge(object@protval, object@metadata@metadata, by.x="msrun", by.y="row.names")
	tprot <- merge(tprot, object@samples, by.x="msrun", by.y="row.names")
	tprot <- merge(tprot, object@proteins, by.x="protein", by.y="row.names")

	if (is.null(flist)){
		tacp= tapply (tprot$q, list(tprot$accession,tprot$msrunfile), FUN=mean)
		dim1=nrow(tacp)
		tacp=na.omit(tacp)
		dim2=nrow(tacp)
	}else{
		if(length(flist)==1){
			tprot$echantillon=tprot[, flist]
			tacp= tapply (tprot$q, list(tprot$accession,tprot$echantillon), FUN=mean, na.rm=TRUE)
			dim1=nrow(tacp)
			tacp=na.omit(tacp)
			dim2=nrow(tacp)
		}
		if(length(flist)>1){
			tprot$echantillon=apply(tprot[,colnames(tprot) %in% flist], 1, paste, collapse="-")
			tacp= tapply (tprot$q, list(tprot$accession,tprot$echantillon), FUN=mean, na.rm=TRUE)
	 		dim1=nrow(tacp)
			tacp=na.omit(tacp)
			dim2=nrow(tacp)
			tacp=tacp[,order(colnames(tacp))]
		}
	}
		
	if (dim1!=dim2){
		warning(paste("Your dataset contains ", dim1-dim2, " out of ", dim1, " proteins that are completely missing in some samples or in some levels of your flist. These proteins are not represented on the heatmap.", sep=""))
	}
	
	# control variability
	ind <- apply(tacp, 1, var) == 0
	tacp <- tacp[!ind,]
	
	if(length(which(ind==TRUE))>0){
		warning(paste("Your dataset contains ",length(which(ind==TRUE))," out of ", dim1, " proteins that have no variability.These proteins are not represented on the heatmap.", sep=""))
	}
	
	ech <- apply(tacp, 2, var) == 0
	tacp <- tacp[,!ech]
	
	if(length(which(ech==TRUE))>0){
		warning(paste("Your dataset contains ",length(which(ech==TRUE))," out of ", length(ech), " samples that have no variability.These samples are not represented on the heatmap.", sep=""))
	}

	if (is.null(factorToColor)){
		classvec=NULL
	}else{
		if(length(factorToColor)==1){
			class.tab=unique(tprot[,c("echantillon", flist)])
			class.tab=class.tab[order(class.tab$echantillon),]
			classvec=class.tab[,factorToColor]	
		}
		if(length(factorToColor)>1){
			class.tab=unique(tprot[,c("echantillon", flist)])
			class.tab=class.tab[order(class.tab$echantillon),]
			classvec=apply(class.tab[,colnames(class.tab) %in% factorToColor], 1, paste, collapse="-")	
		}
	}


	# draw heatmap 
	if (is.null(file)){
		par(ask=FALSE)
	}else{
		pdf(file, title=gsub('.pdf$','',file))
	}
	
	heatplot(tacp, dualScale=FALSE, scale="row", method=method, distfun=distfun, classvec=classvec, cexCol=cexCol, cexRow=cexRow)

	if (!is.null(file)){
		dev.off()
	}

}

