
mcq.plot.intensity.profile <- function (object, factorToColor=NULL, RTinterval=250, file=NULL) {

  # control object
	if ((class(object) == "mcqProtPep") || (class(object) == "mcq.skyline")) {
	}else{
		stop(paste("The class \"", class(object),"\" is not taken into account by mcq.plot.intensity.profile.",sep=""))
	}

  # control parameters : factorToColor
	if (!is.null(factorToColor)) {
		if(length(factorToColor)>1){
			stop("Please choose only one factor for the 'factorToColor' argument.")
		}
		if(!factorToColor %in% colnames(object@metadata@metadata)) {
			stop(paste("The factor ", factorToColor, " chosen for factorToColor is not described in your metadata\n", "please choose one in: ", paste(colnames(object@metadata@metadata),collapse=", "), "\n", sep=""))
		}
	}

	if(is.null(factorToColor)){
		color="darkblue"	
	}else{
		color.tab=object@metadata@metadata
		color.tab$msrun=rownames(object@metadata@metadata)
		color=as.factor(color.tab[,factorToColor])
	}


	tab=merge(object@peptides, object@metadata@metadata, by.x="msrun", by.y="row.names")
	mean.rt=tapply(tab$rt, list(tab$peptiz), mean)
	mean.rt=as.data.frame(mean.rt)
	mean.rt$peptiz=rownames(mean.rt)

	j=round(min(mean.rt$mean.rt),0) 
	RT=j
	jmax=ceiling(max(mean.rt$mean.rt))
	nclass=ceiling((jmax-j)/RTinterval)
	for (i in 1:nclass){
		mean.rt$class[mean.rt$mean.rt>j]=i
		j=j+RTinterval
		RT=c(RT, j)
	}

	indice=match(tab$peptiz, mean.rt$peptiz)
	class=mean.rt$class[indice]

	if (is.null(file)){
		par(ask=FALSE)
	}else{		
		pdf(file, title=gsub('.pdf$','',file), width=15)
	}

	if (is.null(object@peptides$lognorm)) {
		mat=tapply(tab$logarea, list(class, tab$msrun), median)
		matplot(mat, type="l", ylab="Median of Log-intensity", xaxt="n", xlim=c(0.5, nclass+0.5), xlab="Retention time", col=color, lty=1, main="Intensity profile throughout LC-MS run")  
		axis(1, at=c(0.5:(nclass+0.5)), labels=RT, tick=TRUE, las=2)
		if (length(color)>1){
			legend("bottomright", legend=levels(color), col=palette()[1:length(levels(color))], lty=1)
		}
	}else{
		par(mfrow=c(1,2))

		mat=tapply(tab$logarea, list(class, tab$msrun), median)
		matplot(mat, type="l", ylab="Median of Log-intensity", xaxt="n", xlim=c(0.5, nclass+0.5), xlab="Retention time", col=color, lty=1, main=c("Intensity profile throughout LC-MS run", "before normalization"), cex.main=0.8)  
		axis(1, at=c(0.5:(nclass+0.5)), labels=RT, tick=TRUE, las=2)
		if (length(color)>1){
			legend("bottomright", legend=levels(color), col=palette()[1:length(levels(color))], lty=1)
		}

		mat=tapply(tab$lognorm, list(class, tab$msrun), median)
		matplot(mat, type="l", ylab="Median of normalized Log-intensity", xaxt="n", xlim=c(0.5, nclass+0.5), xlab="Retention time", col=color, lty=1, main=c("Intensity profile throughout LC-MS run", "after normalization"), cex.main=0.8)  
		axis(1, at=c(0.5:(nclass+0.5)), labels=RT, tick=TRUE, las=2)
		if (length(color)>1){
			legend("bottomright", legend=levels(color), col=palette()[1:length(levels(color))], lty=1)
		}
	}

	if (!is.null(file)){
		dev.off()
	}
	par(mfrow=c(1,1))

}



