

mcq.plot.ratio= function (object, factor=NULL, numerator=NULL, denominator=NULL, file=NULL, outputfile=NULL) {
	# check the validity of object and factor, numerator and denominator
	if (class(object) != "mcq.protquantity") {
		stop(paste("The object ", object, " is not an mcq.protquantity object.", sep=""))
	}

	if (is.null(factor)) {
		stop("You must choose a factor.")
	}else{
		if (length(factor) > 1) {
			stop("You must choose only one factor.")
		}

	}

	if(!factor %in% names(object@metadata@metadata)) {
		stop(paste("The factor ", factor, " is not described in your metadata."))
	}

	if (is.null(numerator) | is.null(denominator)) {
		stop("You must choose a numerator and a denominator.")
	}

	if(!numerator %in% unique(object@metadata@metadata[,factor])) {
		stop(paste("The numerator", numerator, " is not described in your metadata."))
	}

	if(!denominator %in% unique(object@metadata@metadata[,factor])) {
		stop(paste("The denominator", denominator, " is not described in your metadata."))
	}


	# compute the ratios
	tprot <- merge(object@protval, object@metadata@metadata, by.x="msrun", by.y="row.names")
	tprot <- merge(tprot, object@samples, by.x="msrun", by.y="row.names")
	tprot <- merge(tprot, object@proteins, by.x="protein", by.y="row.names")

	tacp=as.data.frame(tapply(tprot$q,list(tprot$accession,tprot[,factor]),function(x){median(10^x, na.rm=TRUE)}))
	dim1=nrow(tacp)
	tacp=na.omit(tacp)
	dim2=nrow(tacp)
	
	if (dim1!=dim2){
		warning(paste("Your dataset contains ", dim1-dim2, " out of ", dim1, " proteins that are completely missing in some levels of factor ", factor, ". These proteins are not represented in the clusters.", sep=""))
	}

	ratio=tacp[,numerator]/tacp[,denominator]
	ord=order(ratio)
	ratio=log10(ratio[ord])
	names=rownames(tacp)[ord]

	# draw the plot
	if (is.null(file)){
		par(ask=FALSE)
	}
	else{
		pdf(file, title=gsub('.pdf$','',file), height=15)
	}

	color=rep("blue", length(ratio))
	color[ratio>0]="red"	

	xlab.pos=seq(0,max(ratio, na.rm=TRUE), by=0.5)
	xlab.neg=seq(0,min(ratio, na.rm=TRUE), by=-0.5)
	
	barplot(ratio, horiz=TRUE, las=2,names.arg=names, cex.names=0.45, col=color, xaxt="none", xlab="Ratio (log scale)", main=paste("Abundance ratio: ", numerator, "/", denominator, sep="") )
	#axis(1,outer=FALSE,labels=c(round(10^(xlab.neg),1), round(10^(xlab.pos[-1]), 1)),hadj=1,padj=0,las=1,at=c(xlab.neg, xlab.pos[-1]), tick=TRUE)
	axis(1,outer=FALSE,labels=c(xlab.neg,xlab.pos[-1]),hadj=1,padj=0,las=1,at=c(xlab.neg, xlab.pos[-1]), tick=TRUE)
	if (!is.null(file)){
		dev.off()
	}

	# export the outputfile
	if (!is.null(outputfile)){
		out=cbind.data.frame(protein=names, ratio=10^ratio)
		write.table(out, outputfile , quote= FALSE,  sep="\t", dec=".",row.names=F)
	}
}
