
mcq.plot.rt.variability <- function (object, file=NULL, limit = NULL, nclass=100) {
	if (class(object) == "mcqProtPep") {
		peptidgroup=as.factor(paste(object@peptides$peptide,object@peptides$group,sep='-'))
		sdrt=aggregate(object@peptides$rt,list(peptidgroup),FUN=sd)

	}else if (class(object) == "mcq.skyline") {
		peptidgroup=as.factor(object@peptides$peptide)
		sdrt=aggregate(object@peptides$rt,list(peptidgroup),FUN=sd)

	}else{
		if (class(object) != "mcqData") {
			stop("Input is not a mcqData or a mcqProtPep object")
		}
		if (nrow(object@quantipeptides)[[1]] == 0) {
			stop("No quantification results")
		}

		peptidgroup=as.factor(paste(object@peptides$peptide,object@quantify[object$quantipeptides$quantify_id,'group_id'],sep='-'))
		sdrt=aggregate(object@quantipeptides$rt,list(peptidgroup),FUN=sd)
	}

	if (!is.null(file)){
		pdf(file, title=gsub('.pdf$','',file))
	}
	if (is.null(limit)) {
		hist(sdrt$x,nclass=nclass,main="Distribution of the RT variability",xlab="Standard deviation of peptide-mh/z RT (seconds)", border="darkblue")
	}else {
		hist(sdrt$x,nclass=nclass,main="Distribution of the RT variability",xlab="Standard deviation of peptide-mh/z RT (seconds)",xlim = c(0,limit), border="darkblue",)
	}
	mtext(paste("Quantiles: 10% = ", round(quantile(sdrt$x, 0.1, na.rm=TRUE), 1),"; 25% = ",round(summary(sdrt$x)[2], 1),"; 50% = ",round(summary(sdrt$x)[3], 1),"; 75% = ", round(summary(sdrt$x)[5], 1),"; 90% = ", round(quantile(sdrt$x, 0.9, na.rm=TRUE), 1), sep=""),side=3)
	if (!is.null(file)){
		dev.off()
	}
}
