

mcq.read.protpep = function(protFile=NULL, pepFile=NULL, method.ni="max") {

	# Looking for hashtag and apostrophe which impede the correct reading of protFile
	con <- file(protFile, 'r') 
	notempty = TRUE
	line = 0
	while (notempty){ 
		current_line = readLines(con, n=1)
		line = line+1
   		if(length(grep("#", current_line))>0){
			stop(paste("hashtag detected in line ", line, ". Please remove hashtags from ",protFile, " to ensure correct reading.", sep=""))
		}

 		if (length(current_line) >0){
			notempty = TRUE
		}else{
			notempty = FALSE
		}
	}
	close(con) 

	peptides=read.table(pepFile, header=TRUE, sep="\t", dec=".", allowEscapes = FALSE, quote="", stringsAsFactors=FALSE)
	proteins = read.table(protFile, header=TRUE,sep="\t",dec=".", allowEscapes = FALSE, quote="", stringsAsFactors=FALSE)

	peptide_col_names = c("group","msrun","msrunfile","mz" ,"rt"   ,        "maxintensity", "area"    ,     "rtbegin"    ,
			"rtend"      ,  "peptide"   ,   "isotope"    ,  "sequence"  ,   "z"         ,   "mods" )
	for (i in peptide_col_names) {
		if(i %in% colnames(peptides))
		{
		}
		else {
			stop(paste("ERROR in '",pepFile,"' file : peptides dataframe does not contain expected columns. missing '", i, "' column name",sep=""))
			return (NULL)
		}
	}
	protein_col_names = c( "peptide"     ,        "protein",             "protein_description" )
	for (i in protein_col_names) {
		{
			if(i %in% colnames(proteins))
			{
			}
			else {
				stop(paste("ERROR in '",protFile,"' file : proteins dataframe does not contain expected columns. missing '", i, "' column name",sep=""))
				return (NULL)
			}
		}
	}
	#new columns from MassChroQ with natural isotope enabled :
	#	ninumber	nirank	niratio
	if ("ninumber" %in% colnames(peptides)) {
		peptides$peptiz=paste(peptides$peptide,peptides$z,sep='-')
		peptides$peptiniid=as.character(paste(peptides$peptiz, peptides$ninumber, peptides$nirank,sep='-'))

		if (method.ni == "max") {
			warning ("selecting the most theoretically abundant natural isotope among peptiz")
			#take only most intense ratio :
			tab_peptide_ni <- data.frame(peptiniid = unique(peptides$peptiniid))
			temp <- unique(peptides[,c("peptiniid","niratio", "peptiz")])

			tab_peptide_ni <- merge(tab_peptide_ni, temp, by.x="peptiniid", by.y="peptiniid")

			# use aggregate to create new data frame with the maxima
			df.agg <- aggregate(niratio ~ peptiz, tab_peptide_ni, max)
			tab_peptide_ni <- merge(df.agg, tab_peptide_ni)

			peptides <- peptides[peptides$peptiniid %in% tab_peptide_ni$peptiniid,]
		}
		if (method.ni == "mono") {
			warning ("selecting the monoisotope peptiz")
			peptides <- peptides[peptides$ninumber == 0,]
		}


	} else {
		peptides$peptiz=paste(peptides$peptide,peptides$z,sep='-')
	}
	peptides$logarea=log10(peptides$area)


	# parsing accession number
	proteins$protein_description <- str_trim(proteins$protein_description)
	proteins$accession <- word(proteins$protein_description)

	mcqProtPep <- new ("mcqProtPep", peptides = peptides	, proteins = proteins)
	rm (peptides)
	rm (proteins)

	
	if(min(mcqProtPep@peptides$area)==0){
		return(mcq.drop(mcqProtPep,"area", 0))
	}else{
		return(mcqProtPep)
	}

}


