priv.check.protpep = function(object){
	cat("Checking validity\n")
	unique_peptide <- unique(object@proteins$peptide)
	for (peptide in unique(object@peptides$peptide)) {
		if (peptide %in% unique_peptide) {

		}
		else {
			cat(paste(class(object), " ERROR : peptide ",peptide," is not described in proteins\n", sep=""))
			return(FALSE)
		}
	}
	cat(paste(class(object)," object is valid\n", sep=""))
	return(TRUE)
}


priv.check.protq = function(object){
	cat("Checking validity\n")
	if("protein" %in% colnames(object@proteins)) {
		cat(paste(class(object), "@proteins should not have a protein column\n", sep=""))
		return(FALSE)
	}
	if("descr" %in% colnames(object@proteins)) {
	}
	else {
		cat(paste(class(object), "@proteins should have a descr column\n", sep=""))
		return(FALSE)
	}
	if("accession" %in% colnames(object@proteins)) {
	}
	else {
		cat(paste(class(object), "@proteins should have an accession column\n", sep=""))
		return(FALSE)
	}
	for (protein in object@protval$protein) {
		if (protein %in% rownames(object@proteins)) {

		}
		else {
			cat(paste(class(object), " ERROR in protval : protein '",protein,"' is not described\n", sep=""))
			return(FALSE)
		}
	}
	cat(paste(class(object)," object is valid\n", sep=""))
	return(TRUE)
}



priv.mcq.is.protquant.object = function (object) {
	if ((class(object) == "mcq.protquantity") || (class(object) == "mcq.peakcounting") || (class(object) == "mcq.spectralcounting")) {
		return (TRUE)
	}
	return (FALSE)
}


priv.mcq.is.peptidequant.object = function (object) {
	if ((class(object) == "mcqProtPep") || (class(object) == "mcq.skyline") ) {
		return (TRUE)
	}
	return (FALSE)
}


priv.mcq.is.pca.object = function (object) {
	if ((class(object) == "mcq.class.peptide.pca") || (class(object) == "mcq.class.prot.pca")) {
		return (TRUE)
	}
	return (FALSE)
}


priv.summary.protpep.object = function (object) {
	nbxics <- length(object@peptides$peptiz)
	nbpeptiz <- length(unique(object@peptides$peptiz))

	cat (paste("number of proteins : ", length(unique(object@proteins$protein)),"\n", sep=""));
	cat (paste("number of XICs : ", nbxics,"\n", sep=""));
	cat (paste("number of peptiz : ", nbpeptiz,"\n", sep=""));
	cat (paste("number of peptides : ", length(unique(object@peptides$peptide)),"\n", sep=""));
	cat (paste("number of samples : ", length(unique(object@peptides$msrun)),"\n", sep=""));
	if("lognorm" %in% colnames(object@nona)) {
		nbimpxics <- length(object@nona$peptiz)
		cat (paste("number of imputated XIC values : ", (nbimpxics - nbxics),"\n", sep=""));
	}

#pourcentage of missing data :
	compar = mcq.get.compar(object);
	nb_na = sum(is.na(compar))
	cat (paste("number of NA values : ", nb_na,"\n", sep=""));
	cat (paste("% of NA values : ", 100* nb_na/(nrow(compar) * ncol(compar)),"\n", sep=""));

}


priv.summary.protquant.object = function (object) {
	cat (paste("number of proteins : ", length(rownames(object@proteins)),"\n", sep=""));
	cat (paste("number of samples : ", length(rownames(object@samples)),"\n", sep=""));


#pourcentage of missing data :
	compar = mcq.get.compar(object);
	nb_na = sum(is.na(compar))
	cat (paste("number of NA values : ", nb_na,"\n", sep=""));
	cat (paste("% of NA values : ", 100* nb_na/(nrow(compar) * ncol(compar)),"\n", sep=""));

}


privGetMcqPCADudiComponent <- function (object) {
	tco <- object@pca$dudi$co
	if (class(object) == "mcq.class.prot.pca") {
		tco <- cbind.data.frame(accession = rownames(tco), tco)
	}
	else {
		tco <- cbind.data.frame(peptiz = rownames(tco), tco)
	}
	return (tco)
}

privGetMcqPCADudi <- function (object) {
	tacp <- object@pca$dudi$li
	if (is.null(object@pca$factorList)) {
		tacp <- merge(object@samples, tacp, by="row.names")
		colnames(tacp)[which(colnames(tacp)=="msrunfile")]="sample"
		rownames(tacp)=tacp$Row.names
		tacp$Row.names <- NULL
	}
	else {
		tacp <- cbind.data.frame(newcol = rownames(tacp), tacp)
		newcolname <- paste(object@pca$factorList,collapse="/")
		#print (newcolname)
		colnames(tacp)[1]<- newcolname
	}
	return (tacp)
}

privMcqPlotPCA = function (object, factorToColor=NULL, file=NULL, labels=NULL) {

  # control PCA object
	if("dudi" %in% names(object@pca)) {

	}else {
		stop(paste("No PCA made in ",class(object)," object", rep=""))
	}

  # control parameters : factorToColor
	if (is.null(factorToColor)) {
	} else {
		if((length(factorToColor) > length(object@pca$factorList)) & (length(object@pca$factorList)>0)){
			stop(paste("Too many factors chosen for factorToColor (", factorToColor, "), please choose one in: ", object@pca$factorList,"\n",sep=""))
		}

		if((length(object@pca$factorList)>0) & (length(which(!factorToColor %in% object@pca$factorList))>0)){
			stop(paste("The factors chosen for factorToColor are not in agreement with those selected for flist in the mcq.pca function."))
		}
		for (color in factorToColor){
			if(color %in% colnames(object@metadata@metadata)) {
			}else {
				stop(paste("The factor ", color, " chosen for factorToColor is not described in your metadata\n", "please choose one in: ", paste(colnames(object@metadata@metadata),collapse=", "), "\n", sep=""))
			}
		}
	}

  # control parameters : labels
	if (is.null(labels)) {
	} else {
		if((length(labels) > length(object@pca$factorList)) & (length(object@pca$factorList)>0)){
				stop(paste("Too many factors chosen for labels (", labels, "), please choose in : ", object@pca$factorList,"\n",sep=""))
		}
		if((length(object@pca$factorList)>0) & (length(which(!labels %in% object@pca$factorList))>0)){
				stop(paste("The factors chosen for labels are not in agreement with those selected for flist in the mcq.pca function."))
		}
		for (k in labels){
			if(k %in% colnames(object@metadata@metadata)) {
			}else {
				stop(paste("The factor ", k, " chosen for labels is not described in your metadata\n", "please choose one : ", paste(colnames(object@metadata@metadata),collapse=", "), "\n", sep=""))
			}

		}
	}

  # control nb axis
	nbaxis <- length(object@pca$dudi$li)
	if (nbaxis < 2) {
		stop(paste("Unable to plot: the number of axes (", nbaxis, ") is not enough." ,sep=""))
	}

  # PCA dudi information
	tacp <- privGetMcqPCADudi(object)

  # Creation of labelList
	if (is.null(labels)) {
		if (is.null(object@pca$factorList)) {
			tacp<-merge(tacp,object@metadata@metadata, by="row.names")
			labelList <- tacp[,2]
		}
		if (length(object@pca$factorList)==1) {
			labelList <- rownames(tacp)
		}
		if (length(object@pca$factorList)>1) {
			temp=unique(object@metadata@metadata[,colnames(object@metadata@metadata) %in% object@pca$factorList])
			rownames(temp)=apply(temp, 1, paste, collapse="-")
			tacp=merge(tacp, temp, by="row.names")
			rownames(tacp)=tacp$Row.names
			tacp$Row.names <- NULL
			labelList<- rownames(tacp)
		}
	}

	if (length(labels)== 1){
		if (is.null(object@pca$factorList)) {
			tacp<-merge(tacp,object@metadata@metadata, by="row.names")
			labelList <- tacp[,labels]
		}
		if (length(object@pca$factorList)==1) {
			labelList <- tacp[,labels]
		}
		if (length(object@pca$factorList)>1) {
			temp=unique(object@metadata@metadata[,colnames(object@metadata@metadata) %in% object@pca$factorList])
			rownames(temp)=apply(temp, 1, paste, collapse="-")
			tacp=merge(tacp, temp, by="row.names")
			rownames(tacp)=tacp$Row.names
			tacp$Row.names <- NULL
			labelList <- tacp[,labels]
		}
	}

	if (length(labels)>1){
		if (is.null(object@pca$factorList)) {
			tacp <- merge(tacp,object@metadata@metadata, by="row.names")
			labelList <- paste(tacp[,labels[1]],tacp[,labels[2]], sep="-" )
			if (length(labels)>2){
				for (i in 3:length(labels)){
					labelList <- paste(labelList,tacp[,labels[i]], sep="-" )
				}
			}

		}else{
			temp=unique(object@metadata@metadata[,colnames(object@metadata@metadata) %in% object@pca$factorList])
			rownames(temp)=apply(temp, 1, paste, collapse="-")
			tacp=merge(tacp, temp, by="row.names")
			rownames(tacp)=tacp$Row.names
			tacp$Row.names <- NULL
			labelList <- paste(tacp[,labels[1]],tacp[,labels[2]], sep="-" )
			if (length(labels)>2){
				for (i in 3:length(labels)){
					labelList <- paste(labelList,tacp[,labels[i]], sep="-" )
				}
			}
		}
	}
	names(tacp)[names(tacp)=="sample.y"] <- "sample"

  # Creation of colorList
	colorList <- "1"  #default
	cc <- c("black","red","green4","blue","cyan","wheat1","magenta","yellow","gray","darkorange", "brown", "purple", "yellowgreen","turquoise",  "antiquewhite2", "aquamarine",  "aquamarine4",  "chartreuse3", "chocolate" , "coral", "darkred", "darksalmon",  "darkseagreen1","darkslateblue",  "darkslategray1","darkturquoise" , "darkviolet" , "deeppink", "deeppink4", "goldenrod3", "goldenrod4","burlywood3", "lightgreen")
	palette(cc)
	dev.off() 

	if (!is.null(factorToColor)) {
	  if (length(factorToColor)>1) {
		colorList <- as.factor(as.vector(apply( tacp[ , colnames(tacp) %in% factorToColor] , 1 , paste , collapse = "-" )))
	  } else {
		colorList <- as.factor(tacp[,factorToColor])
	  }
	  displayLegend <- TRUE
	}else{
	  displayLegend <- FALSE
	}

  # Graphic representation
	if (!is.null(file)){
	  pdf(file, title=gsub('.pdf$','',file))
	}

	sm = sum(object@pca$dudi$ei)
	pound = round((object@pca$dudi$e/sm*100),digits = 1)
	max1 <- max(object@pca$dudi$li[,1])+0.1*(max(object@pca$dudi$li[,1]))
	min1 <- min(object@pca$dudi$li[,1])-0.1*(abs(min(object@pca$dudi$li[,1])))
	max2 <- max(object@pca$dudi$li[,2])+0.1*(max(object@pca$dudi$li[,2]))
	min2 <- min(object@pca$dudi$li[,2])-0.1*(abs(min(object@pca$dudi$li[,2])))

	par(mfrow = c(2,floor(nbaxis/2)),oma=c(0,0,3,0),pty="s",mex=0.7)
	plot(tacp[,c("Axis1","Axis2")],type="n",xlab=paste("Axis 1 (",pound[1],"%)",sep=""),ylab=paste("Axis 2 (",pound[2],"%)",sep=""), xlim=c(min1,max1), ylim=c(min2,max2))
	text(tacp[,c("Axis1","Axis2")],labels=labelList,cex=0.8, col=as.integer(colorList))
	abline(h=0,lty=2,col="grey")
	abline(v=0,lty=2,col="grey")
	if (displayLegend) {
	legend("topright", legend = unique(colorList), col = unique(as.integer(colorList)), pch = 15, bty = "n",cex=0.6)
	}

	if (nbaxis > 2) {
		max3 <- max(object@pca$dudi$li[,3])+0.1*(max(object@pca$dudi$li[,3]))
		min3 <- min(object@pca$dudi$li[,3])-0.1*(abs(min(object@pca$dudi$li[,3])))
		plot(tacp[,c("Axis2","Axis3")],type="n",xlab=paste("Axis 2 (",pound[2],"%)",sep=""),ylab=paste("Axis 3 (",pound[3],"%)",sep=""), xlim=c(min2,max2), ylim=c(min3,max3))
		text(tacp[,c("Axis2","Axis3")],labels=labelList,cex=0.8, col=as.integer(colorList))
		abline(h=0,lty=2,col="grey")
		abline(v=0,lty=2,col="grey")
	  if (displayLegend) {
		legend("topright", legend = unique(colorList), col = unique(as.integer(colorList)), pch = 15, bty = "n",cex=0.6)
	  }

	  if (nbaxis > 3) {
		max4 <- max(object@pca$dudi$li[,4])+0.1*(max(object@pca$dudi$li[,4]))
		min4 <- min(object@pca$dudi$li[,4])-0.1*(abs(min(object@pca$dudi$li[,4])))
		plot(tacp[,c("Axis3","Axis4")],type="n",xlab=paste("Axis 3 (",pound[3],"%)",sep=""),ylab=paste("Axis 4 (",pound[4],"%)",sep=""), xlim=c(min3,max3), ylim=c(min4,max4))
		text(tacp[,c("Axis3","Axis4")],labels=labelList,cex=0.8, col=as.integer(colorList))
		abline(h=0,lty=2,col="grey")
		abline(v=0,lty=2,col="grey")
	    if (displayLegend) {
		legend("topright", legend = unique(colorList), col = unique(as.integer(colorList)), pch = 15, bty = "n",cex=0.6)
	    }

	    if (nbaxis > 4) {
		max5 <- max(object@pca$dudi$li[,5])+0.1*(max(object@pca$dudi$li[,5]))
		min5 <- min(object@pca$dudi$li[,5])-0.1*(abs(min(object@pca$dudi$li[,5])))
		plot(tacp[,c("Axis4","Axis5")],type="n",xlab=paste("Axis 4 (",pound[4],"%)",sep=""),ylab=paste("Axis 5 (",pound[5],"%)",sep=""), xlim=c(min4,max4), ylim=c(min5,max5))
		text(tacp[,c("Axis4","Axis5")],labels=labelList,cex=0.8,col=as.integer(colorList))
		abline(h=0,lty=2,col="grey")
		abline(v=0,lty=2,col="grey")
	      if (displayLegend) {
		legend("topright", legend = unique(colorList), col = unique(as.integer(colorList)), pch = 15, bty = "n",cex=0.6)
	      }
	    }
	  }
	}
	mtext("PCA", side=3, line=1.5,outer=TRUE)

	if (is.null(file)){
	par(ask=TRUE)
	}
	par(mfrow = c(1,1),oma=c(0,0,0,0),pty="m")
	barplot(pound,main="Axes weights",ylab="weights (%)",xlab="Axes (nb)",names.arg=seq(1:length(pound)))

	if (is.null(file)){
	par(ask=TRUE)
	}
	par(pty="s")
	plot(object@pca$dudi$co[,c("Comp1","Comp2")],xlab=paste("Component 1",sep=" "), ylab=paste("Component 2",sep=" "),pch=19,cex=0.2,ylim=c(-1,1),xlim=c(-1,1))
	title("Correlation circle")
	symbols(0,0,circles=1, inches=F, add=T)
	abline(h=0,lty=2,col="grey")
	abline(v=0,lty=2,col="grey")
	par(pty="m")

	if (!is.null(file)){
	  dev.off()
	}
}

priv.mcq.plot.counts.per.sample = function (object, file=NULL) {
	ni.tot.p.ech=aggregate(object@protval$q,list(object@protval$msrun),FUN=sum)
	colnames(ni.tot.p.ech)=c("msrun", "nb.counts")

	if (!is.null(file)){
		pdf(file, title=gsub('.pdf$','',file), width=15)
	}

	sdni=sd(ni.tot.p.ech$nb.counts)
	mni=mean(ni.tot.p.ech$nb.counts)

	par(mfrow=c(1,2))

	if (class(object) == "mcq.peakcounting"){	
		plot(ni.tot.p.ech$nb.counts, las=2, ylab="Number of peaks", col="darkblue", type="h", xaxt="none", xlab="", main="Number of peaks per sample", cex.axis=0.8, ylim=c(0, max(ni.tot.p.ech$nb.counts)))
		axis(1,outer=FALSE, labels=ni.tot.p.ech$msrun, hadj=1, padj=0, las=2, at=c(1:length(ni.tot.p.ech$msrun)), tick=TRUE, cex.axis=0.8)
		mtext(paste("sd=", round(sdni,1), ", mean=", round(mni,1), sep=""), side=3)

		plot(ni.tot.p.ech$nb.counts, las=2, ylab="Number of peaks", col="darkblue", type="h", xaxt="none", xlab="", main="Zoom on y axis", cex.axis=0.8)
		axis(1,outer=FALSE, labels=ni.tot.p.ech$msrun, hadj=1, padj=0, las=2, at=c(1:length(ni.tot.p.ech$msrun)), tick=TRUE, cex.axis=0.8)
		mtext(paste("sd=", round(sdni,1), ", mean=", round(mni,1), sep=""), side=3)
	}else{
		plot(ni.tot.p.ech$nb.counts, las=2, ylab="Number of spectra", col="darkblue", type="h", xaxt="none", xlab="", main="Number of spectra per sample", cex.axis=0.8, ylim=c(0, max(ni.tot.p.ech$nb.counts)))
		axis(1,outer=FALSE, labels=ni.tot.p.ech$msrun, hadj=1, padj=0, las=2, at=c(1:length(ni.tot.p.ech$msrun)), tick=TRUE, cex.axis=0.8)
		mtext(paste("sd=", round(sdni,1), ", mean=", round(mni,1), sep=""), side=3)

		plot(ni.tot.p.ech$nb.counts, las=2, ylab="Number of spectra", col="darkblue", type="h", xaxt="none", xlab="", main="Zoom on y axis", cex.axis=0.8)
		axis(1,outer=FALSE, labels=ni.tot.p.ech$msrun, hadj=1, padj=0, las=2, at=c(1:length(ni.tot.p.ech$msrun)), tick=TRUE, cex.axis=0.8)
		mtext(paste("sd=", round(sdni,1), ", mean=", round(mni,1), sep=""), side=3)
	}

	if (!is.null(file)){
		dev.off()
	}
	par(mfrow=c(1,1))
}

privcorrpept=function(object, factorName, myprot,seuil.corr) {
	if ((class(object) == "mcqProtPep") || (class(object) == "mcq.skyline")) {
		if("lognorm" %in% colnames(object@peptides)) {

		}else {
			stop("mcqProtPep object is not normalized")
		}
		subprot <- object@proteins[object@proteins$protein==myprot,]
		#print (subprot)

		sub <- object@peptides[object@peptides$peptide %in% subprot$peptide,c("msrun","lognorm","peptiz")]

		#print (sub[1:10,])
		#sub=tabok[tabok$protein==myprot,]
		#toto=tapply(sub$lognorm,list(sub$extraction,as.character(sub$peptiz)),FUN=mean,na.rm=T)
		sub <- merge(sub, object@metadata@metadata, by.x="msrun", by.y="row.names")
		toto=tapply(sub$lognorm,list(sub[,factorName],as.character(sub$peptiz)),FUN=mean,na.rm=T)

		ccc=cor(toto,use="pairwise.complete.obs")
		diag(ccc)=0
		ddd=ccc>seuil.corr
		ddd=apply(ddd,1,FUN=sum,na.rm=T)
		if (max(ddd)>0) {
			eee=ddd[ddd==max(ddd)]
			fff=names(eee[1])
			colok=ccc[which(colnames(ccc)==fff),]
			pepok=c(fff,names(colok[colok>seuil.corr]))
			# on ne veut pas plus de 30 peptiz par protéine. Sinon, risque de pb dans le modèle mixte (calcul du ddl).
			# donc si le nb de peptides corrélés est >30 on augmente le seuil jusqu'à ce qu'il passe en dessous.
			#de cette manière on réduit la liste en gardant les mieux corrélés entre eux.
			while(length(pepok)>30 & seuil.corr<1) {
				seuil.corr=seuil.corr+0.05
				cat(c("protein et seuil correlation",myprot,seuil.corr,"\n"))
				pepok=c(fff,names(colok[colok>seuil.corr]))
			}
		}
		else {
			pepok=NULL
		}
		return(pepok)
	}
	else {
		stop(paste("the class \"", class(object),"\" is not taken into account by privcorrpept",sep=""))
	}
}

priv.mcq.is.anova.object = function (object) {
	if ((class(object) == "mcq.protquantity.anova") || (class(object) == "mcq.peakcounting.anova") || (class(object) == "mcq.spectralcounting.anova")) {
		return (TRUE)
	}
	return (FALSE)
}

priv.mcq.anova= function (object, flist=NULL, Tukey=c(), alpha=0.05) {
	factorList <- flist
	if (is.vector(factorList)) {

	}
	else {
		factorList <- c(factorList)
	}

	if (is.vector(Tukey)) {

	}
	else {
		Tukey <- c(Tukey)
	}
	protval <- object@protval
	if (class(object) == "mcq.protquantity") {
		newObject <- new ("mcq.protquantity.anova", protval =  object@protval , metadata =  object@metadata, proteins = object@proteins, samples = object@samples, paramlist= list(), resultanov = data.frame(), resulttukey=list())
	} else if (class(object) == "mcq.spectralcounting") {
		newObject <- new ("mcq.spectralcounting.anova", protval =  object@protval , metadata =  object@metadata, proteins = object@proteins, samples = object@samples, paramlist= list(), resultanov = data.frame(), resulttukey=list())
	} else if (class(object) == "mcq.peakcounting") {
		newObject <- new ("mcq.peakcounting.anova", protval =  object@protval , metadata =  object@metadata, proteins = object@proteins, samples = object@samples, paramlist= list(), resultanov = data.frame(), resulttukey=list())
	}
	newObject@paramlist$factorList <- factorList
	newObject@paramlist$factorListTuckey <- Tukey
	newObject@paramlist$interactionList <- c()
	if (length(factorList) == 2) {
		newObject@paramlist$interactionList <- c(paste(factorList, collapse="__"))
	}
	if (length(factorList) == 3) {
		newObject@paramlist$interactionList <- c(paste(factorList[c(1,2)], collapse="__"),
				paste(factorList[c(1,3)], collapse="__"),
				paste(factorList[c(2,3)], collapse="__"),
				paste(factorList, collapse="__"))
	}
	if (length(factorList) > 3) {
		stop(paste("too much factors in your factor list"))
	}
	for (factorName in factorList) {
		if (factorName %in% colnames(newObject@metadata@metadata)) {

		}
		else {
			stop(paste("the factor ",factorName," is not described in your metadata"))
		}
	}
	options(contrasts=c("contr.sum","contr.sum"))
	tabLevels <- unique((protval$protein))
	nbprot<- length(tabLevels)
	ni <- protval[,c("msrun", "protein", "q")]
	ni <- merge (ni, newObject@metadata@metadata, by.x="msrun", by.y="row.names")
	resulttukey <- list()
	resultmodel <- list()
	
	matrixModel <- NULL
	
	for (ip in 1:nbprot){
		myprot <- tabLevels[ip]
		tabcour <- ni[ni$protein==myprot,]

		resultByFactor <- c()

		if (class(object) == "mcq.protquantity") {
			ifactor <- 0
			resultmodel[myprot] <-list(aov(as.formula(paste("q~",paste(factorList, collapse='*'),sep="")), data=tabcour))
			if (length(Tukey) > 0) {
				for (factorName in factorList) {
					tabcour[,factorName]=as.factor(tabcour[,factorName])
					resultmodel[myprot] <-list(aov(as.formula(paste("q~",paste(factorList, collapse='*'),sep="")), data=tabcour))
				}
				#agricolae Tukey :
				#tuktest=HSD.test(lm.prot, alpha=alpha,Tukey, group=TRUE)
				#standard library :
				#tuktest=TukeyHSD(resultmodel[[myprot]],Tukey, conf.level=1-alpha, ordered=TRUE)
				#multcomp library
				#tuktest=glht(resultmodel[[myprot]],linfct=mcp(Tukey="Tukey")) doesn't work
				#Need to construct a character string with the expression for linear function.
				exprString <- paste("mcp(", Tukey, "='Tukey')")
				#eval(parse()) : to get an 'mcp' object.
				LINFCT <- eval(parse(text = exprString))
				tuktest=glht(resultmodel[[myprot]],linfct=LINFCT)
				resulttukey[myprot] <- list(tuktest)
			}
			for (factorName in factorList) {
				ifactor <- ifactor+1
				resultByFactor[factorName]<-anova(resultmodel[[myprot]])["Pr(>F)"][[1]][ifactor]
			}
			if (sum(is.na(resultByFactor)) == length(factorList)) {
				for (factorName in factorList) {
					resultByFactor[factorName] <- NA
				}
				for (factorName in newObject@paramlist$interactionList) {
					resultByFactor[factorName] <- NA
				}
			}
			else {
				for (factorName in newObject@paramlist$interactionList) {
					ifactor <- ifactor+1
					resultByFactor[factorName]<-anova(resultmodel[[myprot]])["Pr(>F)"][[1]][ifactor]
				}
			}
		}else{
			ifactor <- 1
			tmp <-glm(as.formula(paste("q~",paste(factorList, collapse='*'),sep="")), data=tabcour,family="poisson")
			resultByFactor["proba.good.model"]<-as.numeric(pchisq(tmp$deviance,tmp$df.residual,lower.tail=FALSE))
			for (factorName in factorList) {
				ifactor <- ifactor+1
				resultByFactor[factorName]<-anova(tmp,test="Chisq")["Pr(>Chi)"][[1]][ifactor]
			}
			for (factorName in newObject@paramlist$interactionList) {
				ifactor <- ifactor+1
				resultByFactor[factorName]<-anova(tmp,test="Chisq")["Pr(>Chi)"][[1]][ifactor]
			}
		}
		if (is.null(matrixModel)) {
				matrixModel <- matrix (resultByFactor, ncol=length(resultByFactor), nrow=nbprot)
		}else {
				matrixModel[ip,]<-resultByFactor
		}
		if (ip%%10==0) cat(paste(ip," proteins\n"))
	}
	newObject@resulttukey <- resulttukey

	newObject@resultanov <- data.frame(matrixModel)
	rownames(newObject@resultanov) <- tabLevels

	#rename column :
	colnames(newObject@resultanov) <- names (resultByFactor)

	return (newObject)

}

priv.check.anova.factor <-function (object, factor=NULL) {
	if (is.null(object@resultanov)) {
		stop("there is no anova results in your object")
	}
	if (nrow(object@resultanov) == 0) {
		stop("there is no anova results in your object")
	}
	ni <- object@protval
	ni <- merge (ni, object@metadata@metadata, by.x="msrun", by.y="row.names")
	factorName <- factor
	factorList <- colnames(object@metadata@metadata)
	if (is.null(factorName)) {
		if (length(factorList) > 1) {
			stop(paste("You must choose a factor to select significantly different proteins (add the parameter factor=).\n",
							"available factors are : ", paste(factorList,collapse=", "), "\n", sep=""))
		}
		factorName <- factorList[1]
	}
	if (factorName %in% colnames(object@metadata@metadata)) {
	}
	else {
		stop(paste("the factor ",factorName," is not described in your metadata", sep=""))
	}
	if (factorName %in% colnames(object@resultanov)) {
	}
	else {
		stop(paste("the factor ",factorName," is not described in the results of the anova", sep=""))
	}
	return (factorName)
}

priv.anova.select.signif <-function (object, ok.signif) {

	nbProt = length(ok.signif)
	object@resultanov$bidonnage <- object@resultanov[,1]
	object@resultanov <- object@resultanov[ok.signif,]
	object@resultanov$bidonnage <- NULL
	newNbProt <- length(rownames(object@resultanov))

	cat (paste(newNbProt," proteins selected. ", (nbProt - newNbProt), " proteins dropped\n", sep=""))

#cleaning object slots
	object@protval <- object@protval[object@protval$protein %in% rownames(object@resultanov),]

	msrunlist <- unique(object@protval$msrun)
	object@metadata@metadata$bidon <- rownames(object@metadata@metadata)
	object@metadata@metadata <- object@metadata@metadata[msrunlist,]
	object@metadata@metadata$bidon <- NULL

#proteins="data.frame"
	object@proteins <- object@proteins[rownames(object@resultanov),]

#samples
	object@samples$bidonnage <-rownames(object@samples)
	object@samples <- object@samples[msrunlist,]
	object@samples$bidonnage <- NULL

#resulttukey
	object@resulttukey <- object@resulttukey[ok.signif]

	return (object)
}


priv.mcq.select.anova.signif <-function (object, pvalue, factor) {

	factorName <- priv.check.anova.factor(object, factor);
	object@paramlist$pvaluethreshold <- pvalue
	object@paramlist$factorsignif <- factorName


	ok.signif <- (!is.na(object@resultanov[,factorName])) & (object@resultanov[,factorName]<pvalue)

	return (priv.anova.select.signif (object, ok.signif))
}



priv.mcq.select.mindiff <-function (object, mindiff=mindiff, factor=NULL) {
	## Selection of proteins showing a minimal difference betwwen the two extrem treatments.
	ni <- object@protval
	ni <- merge (ni, object@metadata@metadata, by.x="msrun", by.y="row.names")
	ni <- merge (ni, object@proteins, by.x="protein", by.y="row.names")
	factorName <- factor
	factorList <- colnames(object@metadata@metadata)
	if (is.null(factorName)) {
		if (length(factorList) > 1) {
			stop(paste("You must choose a factor.\n",
							"Available factors are : ", paste(factorList,collapse=", "), "\n", sep=""))
		}
		factorName <- factorList[1]
	}

	if (factorName %in% colnames(object@metadata@metadata)) {
	}
	else {
		stop(paste("The factor ",factorName," is not described in your metadata.", sep=""))
	}

	protlist <- mcq.get.protlist(object);
	tabLevels <- names(protlist@proteins)
	nbprot<- length(tabLevels)

	result.diff <- numeric(nbprot)
	names(result.diff) <- tabLevels
	for (ip in 1:nbprot){
		myprot=tabLevels[ip]
		tabcour=ni[ni$accession==myprot,]
		mmm=aggregate(tabcour$q,list(tabcour[,factorName]),FUN=mean)
		max.mean=max(mmm$x)
		min.mean=min(mmm$x)
		result.diff[myprot]=max.mean-min.mean

		if (ip%%10==0) cat(paste(ip," proteins\n"))
	}

	result.diff <- result.diff[result.diff > mindiff]

	newNbProt <- length(result.diff)

	cat (paste(newNbProt," proteins selected. ", (nbprot - newNbProt), " proteins dropped\n", sep=""))

	protlist <- new ("mcq.protlist", proteins = protlist@proteins[names(result.diff)])

	return (mcq.select.protlist(object,protlist))

}


priv.mcq.glm = function (object, factorList, alpha = 0.05) {
	if (is.vector(factorList)) {

	}
	else {
		factorList <- c(factorList)
	}
	protval <- object@protval
	if (class(object) == "mcq.protquantity") {
		newObject <- new ("mcq.protquantity.glm", protval =  object@protval , metadata =  object@metadata, proteins = object@proteins, samples = object@samples, paramlist= list(), resultglm = data.frame())
	} else if (class(object) == "mcq.spectralcounting") {
		newObject <- new ("mcq.spectralcounting.glm", protval =  object@protval , metadata =  object@metadata, proteins = object@proteins, samples = object@samples, paramlist= list(), resultglm = data.frame())
	} else if (class(object) == "mcq.peakcounting") {
		newObject <- new ("mcq.peakcounting.glm", protval =  object@protval , metadata =  object@metadata, proteins = object@proteins, samples = object@samples, paramlist= list(), resultglm = data.frame())
	}

	newObject@paramlist$factorList <- factorList
	newObject@paramlist$interactionList <- c()

	if (length(factorList) == 2) {
		newObject@paramlist$interactionList <- c(paste(factorList, collapse="__"))
	}
	if (length(factorList) == 3) {
		newObject@paramlist$interactionList <- c(paste(factorList[c(1,2)], collapse="__"),
				paste(factorList[c(1,3)], collapse="__"),
				paste(factorList[c(2,3)], collapse="__"),
				paste(factorList, collapse="__"))
	}
	if (length(factorList) > 3) {
		stop(paste("too much factors in your factor list"))
	}

	for (factorName in factorList) {
		if (factorName %in% colnames(newObject@metadata@metadata)) {

		}
		else {
			stop(paste("the factor ",factorName," is not described in your metadata"))
		}
	}

	tabLevels <- unique(as.character(protval$protein))
	nbprot<- length(tabLevels)
	ni <- protval[,c("msrun", "protein", "q")]
	ni <- merge (ni, newObject@metadata@metadata, by.x="msrun", by.y="row.names")
	newObject@resultglm <- data.frame()
	#resultglm <- list()
	matrixGlm <- NULL

	for (ip in 1:nbprot){
		myprot <- tabLevels[ip]
		tabcour <- ni[ni$protein==myprot,]

		tmp <-glm(as.formula(paste("q~",paste(factorList, collapse='*'),sep="")), data=tabcour,family="poisson")
		good.model=with(tmp,cbind(res.deviance=deviance,df=df.residual,p=pchisq(deviance,df.residual,lower.tail=FALSE)))
		proba.good.model=as.vector(good.model[,"p"])

		resultByFactor <- c()
		ifactor <- 1

		resultByFactor["proba.good.model"]<-proba.good.model
		for (factorName in factorList) {
			ifactor <- ifactor+1
			resultByFactor[factorName]<-anova(tmp,test="Chisq")["Pr(>Chi)"][[1]][ifactor]
		}
		for (factorName in newObject@paramlist$interactionList) {
			ifactor <- ifactor+1
			resultByFactor[factorName]<-anova(tmp,test="Chisq")["Pr(>Chi)"][[1]][ifactor]
		}
		if (is.null(matrixGlm)) {
			matrixGlm <- matrix (rep("NA",time=length(resultByFactor)*nbprot), ncol=length(resultByFactor), nrow=nbprot)
			matrixGlm[ip,]<-resultByFactor
		}else{
			matrixGlm[ip,]<-resultByFactor
		}
		if (ip%%10==0) cat(paste(ip," proteins\n"))
		newObject@resultglm <- data.frame(matrixGlm)
		rownames(newObject@resultglm) <- tabLevels
		colnames(newObject@resultglm) <- names (resultByFactor)

		return (newObject)
	}
}


privCheckMetadataIn = function (tabin) {
	metadata = data.frame(
			msrun=character(length(tabin[,1])),
			stringsAsFactors=FALSE)
	samples = data.frame(
			msrun=character(length(tabin[,1])),
			stringsAsFactors=FALSE)

	if('msrun' %in% colnames(tabin))
	{
		rownames(metadata) <-  tabin[,'msrun']
		rownames(samples) <-  tabin[,'msrun']
		metadata[,'msrun']  <- NULL
		tabin[,'msrun'] <- NULL
	}
	else {
		stop("ERROR : metadata dataframe does not contain expected column 'msrun'\n")
		return (NULL)
	}
	if('msrunfile' %in% colnames(tabin))
	{
		samples[,'msrunfile'] <- tabin[,'msrunfile']
		tabin[,'msrunfile'] <- NULL
		samples[,'msrun']  <- NULL
	}
	else {
		stop("ERROR : metadata dataframe does not contain expected column 'msrunfile'\n")
		return (NULL)
	}

	for (i in colnames(tabin)) {

		metadata[,i] <- tabin[,i]
	}

	return (list(metadata= metadata, samples = samples))
}


privCheckMetadataCoherence <- function(object) {
	msrunList <- NULL

	if (class(object) == "mcqProtPep") {
		msrunList <- unique(object@peptides$msrun)
	}
	if (class(object) == "mcqSpectralcounting") {
		msrunList <- unique(object@count$msrun)
	}
	if (class(object) == "mcqData") {
	}
	if (!is.null(msrunList)) {
		if (nrow(object@metadata@metadata) != length(msrunList)){
			stop("the number of msrun is different between mcqMetadata and treated object")
		}

		for (msrun in msrunList) {
			if (msrun %in% rownames(object@metadata@metadata)) {

			}
			else {
				stop(paste("the msrun ",msrun," is not described in your metadata"))
			}
		}

		for (msrun in rownames(object@metadata@metadata)) {
			if (msrun %in% msrunList) {

			}
			else {
				stop(paste("the msrun ",msrun," does not exists in your object"))
			}
		}
	}
}

