\name{mcq.drop.variable.rt}

\alias{mcq.drop.variable.rt}

\title{Drop Variable Retention Times}

\description{This function removes from the proteomic dataset the peptides-modification-charge showing too much variation in their retention time.}

\usage{mcq.drop.variable.rt(object, cutoff=20)}

\arguments{
	\item{object}{an object of class 'mcqProtPep' or 'mcq.skyline'}
	\item{cutoff}{a numetical value indicating the standard deviation threshold beyond which the retention time of a given peptide-modification-charge is considered to be too much variable. By default, it is set to 20 seconds}
}
\details{The retention time of a peptide-modification-charge is expected to be poorly variable from one sample to another, especially if aligment has been performed. The peptides-modification-charge showing excessive variation in their retention time are therefore considered as dubious (their may reflect bad identification). For this reason, these peptides-modification-charge are removed from the proteomic dataset. Variability of the retention time is estimated through its standard deviation computed by using all the samples where the peptide-modification-charge was observed. The cutoff value has to be set in agreement with the LC parameters and according to user’s expertise. }

\value{The 'mcq.drop.variable.rt' function returns the input object without peptides-modification-charge showing too much variation in their retention time.}

\references{}

\author{}

\note{}

\seealso{'mcq.plot.rt.variability'}

\examples{

# Preliminary step: load the example dataset and merge metadata to the object of class 'mcqProtPep'
	data(extraction)
	protPep <- mcq.merge.metadata(protPep, metadata.info)
	
# Remove dubious peptides-modification-charge
	protPep.cleaned=mcq.drop.variable.rt(protPep, cutoff=20)
	summary(protPep)
	summary(protPep.cleaned)
}

