\name{mcq.drop.wide.peaks}

\alias{mcq.drop.wide.peaks}

\title{Drop Wide Peaks}

\description{This function removes the chromatographic peaks whose width is larger than a given threshold.}

\usage{mcq.drop.wide.peaks(object, cutoff=100)}

\arguments{
	\item{object}{an object of class 'mcqProtPep'}
	\item{cutoff}{a numetical value indicating the width threshold beyond which the chromatographic peak is considered to be too wide. By default, it is set to 100 seconds}
}

\details{Chromatographic peak widths are computed from the retention times marking the beginning and the end of the peaks (referred to as 'rtbegin' and 'rtend' in the peptides slot of the object of class 'mcqProtPep', respectively). The chromatographic peaks that are too wide are considered as dubious: their may reflect a problem during chromatography or they may correspond to highly abundant peptides that reach the saturation limit of the mass spectrometer). For this reason, these peaks are removed from the proteomic dataset. The cutoff value for width has to be set in agreement with the LC parameters and according to user’s expertise.}

\value{The 'mcq.drop.wide.peaks' function returns the input object without the chromatographic peaks whose width exceeds the cutoff.}

\references{}

\author{}

\note{}

\seealso{'mcq.plot.peak.width'}

\examples{

# Preliminary step: load the example dataset and merge metadata to the object of class 'mcqProtPep'
	data(extraction)
	protPep <- mcq.merge.metadata(protPep, metadata.info)
	
# Remove dubious chromatographic peaks
	protPep.cleaned=mcq.drop.wide.peaks(protPep, cutoff=100)
	summary(protPep)
	summary(protPep.cleaned)
}

