\name{mcq.normalize}

\alias{mcq.normalize}

\title{Normalization of Peak Intensities}

\description{This function performs the normalization of chromatographic peak intensities in order to take into account possible global quantitative variations between LC-MS runs.}

\usage{mcq.normalize(object, refSample=NULL, method="median")}

\arguments{
	\item{object}{an object of class 'mcqProtPep' or 'mcq.skyline'}
	\item{refSample}{a character vector indicating the name of the msrun corresponding to the sample to be used as a reference in the "median" and "median.RT" methods. See the column 'msrun' in the metadata file. By default, reference sample is the sample with the highest number of chromatographic peaks}
	\item{method}{a character vector indicating the normalization method to be used. This must be "percent", "median" or "median.RT" (see details).
}

}
\details{In the "percent" method, intensities of chromatographic peaks within a given sample are divided by the summed intensities of all the peaks of this sample. The intensity values thus obtained are multiplied by the average intensity computed over all the samples in order to obtain normalized intensity values in the same range of values as the initial non-normalized intensities. 

In the "median" method,  intensities of chromatographic peaks within a given sample are first divided by their corresponding value in a sample chosen as reference. The median of all these ratios is then computed. To finish, normalization is performed by dividing each peak intensity in the given sample by the median of peak ratios.

The "median.RT" method is a local normalization method adapted from  Lyutvinskiy et al. (2013, Mol. Cell. Prot. 12(8):2324:2331). Intensity deviation between a given sample and a reference sample is computed for each peptide-modification-charge quantified in both samples. The values of intensity deviation thus obtained are ordered according to the peptides' retention time and smoothed. The smoothed values of intensity deviation are then used as normalization factors.}

\value{The function 'mcq.normalize' returns the input object with normalized peak intensities stored in the peptides slot.}

\references{}

\author{}

\note{}

\seealso{}
\examples{
# Preliminary step: load the example dataset
	data('extraction')

# Normaliztion by the "percent" method. No need to use a reference sample.
	protPep <- mcq.normalize(protPep, method="percent")

# Normalization by the "median" method using a chosen reference sample
	protPep <- mcq.normalize(protPep, refSample="samp0", method="median")

# Normalization by the "median.RT" method 
	protPep <- mcq.normalize(protPep, refSample="samp0", method="median.RT")

}
