\name{mcq.pca}

\alias{mcq.pca}

\title{Principal Component Analysis}
\description{This function performs a principal component analysis using peptide intensities or protein abundances as variables.}
\usage{mcq.pca(object, flist=NULL)}

\arguments{
  \item{object}{an object of class 'peptidequant' or 'proteinquant'}
  \item{flist}{a character vector indicating a factor or a combination of factors whose levels will be considered as individuals. By default, the principal component analysis is performed by considering each sample as an individual}
}

\details{When the 'flist' argument is filled in, average peptide or protein abundances are computed for each of the levels of the chosen factor or combination of factors. These levels are further considered as individuals in the principal component analysis. ‘mcq.pca’ calls ‘dudi.pca’ in the R package ‘ade4’.}

\value{Depending on the input object, the function 'mcq.pca' returns an object of class 'mcq.class.prot.pca' or 'mcq.class.peptide.pca' containing four slots: proteins or peptides, metadata, samples and data pca.}

\references{}

\author{}

\note{}

\seealso{‘dudi.pca’ in the R package ‘ade4’}

\examples{
# Preliminary step: load the example dataset and merge metadata to the object of class 'mcqProtPep'
	data(extraction)
	protPep <- mcq.merge.metadata(protPep, metadata.info)

# Launch the 'mcq.pca' function with default parameters: there are as many individuals as samples. 
	mypca <- mcq.pca(protPep)
	mcq.plot.pca(mypca) # to visualize the results

# Launch a principal component analysis using a factor or a combination of factors as individuals (in this case, average intensities are computed for the factor or for the combination of factors)
	mypca <- mcq.pca(protPep, flist=c("extraction", "rep"))
	mcq.plot.pca(mypca) # to visualize the results
}


