\name{mcq.plot.global.intensity}

\alias{mcq.plot.global.intensity}

\title{Plot Global Intensity per Sample}

\description{This function draws a violin plot showing globally the distribution of the peptide intensities in each sample.}

\usage{mcq.plot.global.intensity(object, factorToColor=NULL, file=NULL)}

\arguments{
\item{object}{an object of class 'mcqProtPep' or 'mcq.skyline'}
\item{factorToColor}{a character vector indicating which factor to highlight}
\item{file}{a character vector indicating the name of the pdf file where to export the graph (e.g. "mygraph.pdf"). By default, the graph is displayed on the screen}
}

\details{When the object of class 'mcqProtPep' or 'mcq.skyline' contains normalized intensity values (in this case, the dataframe in the 'peptides' slot contains columns named 'lognorm' and 'areanorm'), the 'mcq.plot.global.intensity' function displays two graphs: one showing the global peptide intensities before normalization and the other showing the global peptide intensities after normalization.}

\value{The function 'mcq.plot.global.intensity' returns a graph that is displayed on the screen when the file argument is NULL or that is exported as a pdf file when the file argument is filled in.}

\references{}

\author{}

\note{}

\seealso{}

\examples{
# Preliminary step: load the example dataset and merge metadata to the object of class 'mcqProtPep'
	data(extraction)
	protPep <- mcq.merge.metadata(protPep, metadata.info)

# Launch the 'mcq.plot.global.intensity' function with default parameters
	mcq.plot.global.intensity(protPep)

# Draw a violin plot highlighting the levels of the 'extraction' factor
	mcq.plot.global.intensity(protPep, factorToColor="extraction")

# Launch the 'mcq.plot.global.intensity' function after intensity normalization 
	protPep <- mcq.normalize(protPep, refSample="samp0", method="median")
	mcq.plot.global.intensity(protPep, factorToColor="extraction")
}


