\name{mcq.plot.intensity.profile}

\alias{mcq.plot.intensity.profile}

\title{Plot Intensity Profile}

\description{This function draws a plot showing, for each sample, the median peptide intensity throughout the chromatography.}

\usage{mcq.plot.intensity.profile(object, factorToColor=NULL, RTinterval=250, file=NULL)}

\arguments{
\item{object}{an object of class 'mcqProtPep' or 'mcq.skyline'}
\item{factorToColor}{a character vector indicating which factor to highlight}
\item{RTinterval}{integer indicating the width of the sliding window used to compute the median peptide intensity during the chromatography. The wider the window is, the smoother the profile will be}
\item{file}{a character vector indicating the name of the pdf file where to export the graph (e.g. "mygraph.pdf"). By default, the graph is displayed on the screen}
}

\details{When the object of class 'mcqProtPep' or 'mcq.skyline' contains normalized intensity values (in this case, the dataframe in the 'peptides' slot contains columns named 'lognorm' and 'areanorm'), the 'mcq.plot.intensity.profile' function displays two graphs: one showing the intensity profile of each sample before normalization and the other showing the intensity profile of each sample after normalization.}

\value{The function 'mcq.plot.intensity.profile' returns a graph that is displayed on the screen when the file argument is NULL or that is exported as a pdf file when the file argument is filled in.}

\references{}

\author{}

\note{}

\seealso{}

\examples{
# Preliminary step: load the example dataset and merge metadata to the object of class 'mcqProtPep'
	data(extraction)
	protPep <- mcq.merge.metadata(protPep, metadata.info)

# Launch the 'mcq.plot.intensity.profile' function with default parameters
	mcq.plot.intensity.profile(protPep)

# Launch the 'mcq.plot.intensity.profile' function reducing or increasing the RTinterval
	mcq.plot.intensity.profile(protPep, RTinterval=100)
	mcq.plot.intensity.profile(protPep, RTinterval=500)

# Draw a plot highlighting the levels of the 'extraction' factor
	mcq.plot.intensity.profile(protPep, factorToColor="extraction")

# Launch the 'mcq.plot.intensity.profile' function after intensity normalization 
	protPep <- mcq.normalize(protPep, refSample="samp0", method="median")
	mcq.plot.intensity.profile(protPep, factorToColor="extraction")


}


