
# chargement du paquet
	library('MassChroqR')
#	library('gdata')

# changement du répertoire de travail (remplacer /chemin/vers/repertoire_de_travail par votre arborescence)
	setwd ('/tmp')
	getwd()


	protPep <- read.mcq.skyline('/gorgone/pappso/abrf_2015/intensity/SkylineIntensities_na.tsv')

# export d'un template dans lequel pourront être ajouté les métadata
#	mcqWriteMetadataCsv(protPep, 'metadata.csv')

# Ajout des metadata: ouvrir le fichier outfile.csv sous libreoffice ou excel, ajouter des colonnes (par exemple:traitement, rep , génotype, etc. ) permettant de décrire les échantillons et enregistrer en conservant le format csv

# import des métadata
	metadata <- read.mcq.metadata.ods('/gorgone/pappso/abrf_2015/masschroqr_skyline/metadata.ods')

# Ajout des métadata à l'objet protPep
	protPep <- mcq.merge.metadata(protPep, metadata)

# affichage du résumé du contenu de l'objet protPep
	summary (protPep)

	save(protPep, file="protPep.RData")
	load(file="protPep.RData")

# nettoyage des peptiz "surdétectés"
	protPep <- mcq.select.monodetected.peptiz(protPep)


# affichage de l'histogramme de distribution de la déviation des temps de rétention
	mcqPlotRetentionTimeSd(protPep)							# affichage à l'écran et paramètre "limit" par défaut
	mcqPlotRetentionTimeSd(protPep,limit=60, nclass = 300)  # limiter l'affichage des temps de rétention à 40s maximum (ici)
	mcqPlotRetentionTimeSd(protPep, pdf="RT.pdf",limit=40, nclass = 300)  # limiter l'affichage des temps de rétention à 40s maximum (ici)

	summary (protPep)

# suppression des peptides ayant une déviation supérieure à un seuil à déterminer en fonction de l'histogramme précédent (ici, 20 sec)
	protPep <- mcqDropRetentionTimeSd(protPep, cutoff=35)
	summary (protPep)



############################################################################################################################################################################
################################# Analyse quantitative (XIC)   #############################################################################################################
############################################################################################################################################################################

################################# Normalisation des données (les aires sont en log10)

# Visualisation des histogrammes de distribution des intensités de peptide dans chaque échantillon
	mcqPlotDistribQlog(protPep)

# Visualisation des histogrammes de distribution des différences des log d'intensité de peptide entre un échantillon donné et l'échantillon choisi comme référence (ici samp0)
	mcqPlotDistribQlogDiffRef(protPep, '1A', pdf='distrib_visu.pdf')

# Visualisation de la corrélation entre les intensités de peptides mesurées dans un échantillon donné et celles mesurées dans l'échantillon de référence (ici samp0)
	mcqPlotDistribQlogCometDiff(protPep, '1A')

# Normalisation par la médiane des différences d'intensité de peptides
	protPep <- mcqNormalizeBySampleref(protPep, '1A')

# Visualisation de l'effet de la normalisation
	mcqPlotNormalizationEffect(protPep, pdf='normalization_effect.pdf')

	mcq.write.tsv(protPep, csv="skyline_after_norm.tsv")
	mcq.write.compar.tsv(protPep, csv="compar_skyline_after_norm.tsv")

df <- mcq.get.compar(protPep)
head(df)
# Statistiques exploratoires : ACP sur les peptides (peptiz / échantillons)
	peptidepca <- mcqNewPeptidePCA(protPep)

# Statistiques exploratoires : ACP sur les peptides (peptiz / extraction)
#	peptidepca_extraction <- mcqNewPeptidePCA(protPep, "extraction")

# écriture du résultat de l'ACP dans un fichier pour un traitement dans un logiciel externe
	mcq.write.tsv(peptidepca, csv="peptidepca.tsv")

# visualisation des axes de l'ACP

	mcqPlotPeptidePCA(peptidepca, colors="sample")


################################# Filtre des données : sélection des peptides reproductibles, des peptides spécifiques et des peptides corrélés d'une même protéine

# Histogramme du nombre d'échantillons dans lesquels un peptide a été quantifié
	mcq.plot.peptide.reproducibility(protPep, pdf='PeptideRepetables.pdf')

# Suppression des peptides non répétables (présents dans moins de 5% des échantillons)
# pct.max.mq => % max de valeurs manquantes
	protPep <- mcq.drop.unreproducible.peptides(protPep, method="percent", percentCutoff=0.05) 

	summary (protPep)

# Selon nombre de modalités du facteur choisir étape a ou étape b
# a /Si le facteur "traitement" présente au moins 3 conditions (modalités) : filtre sur la correlation entre les peptides d'une même protéine
	protPep <- mcq.drop.uncorrelated.peptides(protPep, 'sample')

	summary (protPep)

# b /Si le facteur "traitement" présente moins de 3 modalités : on ne garde que les protéines quantifiées par au moins 2 peptides
#	protPep = mcqSelect2pepbyprot(protPep,'extraction')
	

################################# Imputation des valeurs manquantes par régression linéaire
	protPepnona <- mcq.data.imputations(protPep, 'sample')



################################# Calcul de la quantité par protéine

# Calcul des quantités de protéine (somme des peptides)
	qprot <- mcq.protquantity(protPepnona)


# Histogramme de distribution des écart-types des quantités de protéine
	mcqPlotProteinValueSd(qprot)
	mcqPlotProteinValueSd(qprot, pdf='SD_logQNorm.pdf')
	head(qprot@protval)

# Export au format tabulé 
	mcq.write.compar.tsv(qprot, 'tacp_na.tsv')

# dans les cas où il n'y avait pas de peptide de la protéine présent dans l'échantillon, on a encore un NA.
# on remplace le NA par la valeur min trouvée pour cette protéine dans l'expérience.
	qprot <- mcqReplaceNaProteinValueByMin(qprot)

	mcq.write.compar.tsv(qprot, 'tacp_nona.tsv')

	mcqPlotProteinValueSd(qprot, pdf ='SD_logQNormMIN.pdf')



# Elimination des protéines qui ne varient pas beaucoup
# cutoff => seuil minimum accepté pour l'écart type en valeur absolue (0.05=trop faible pour une valeur absolue)
# Regarder l'ecart type et adapter en fonction
	test <- mcqDropProteinValueSd(qprot,cutoff=0.05)
	mcqPlotProteinValueSd(test)
	mcqPlotProteinValueSd(qprot)


save (qprot, file="qprot.RData")
load("qprot.RData")
################################# Représentation ACP à partir des quantités de protéine
	pca <- mcqNewProteinPCA(qprot)
# export du résultat de l'ACP dans un fichier pour manipulations dans un logiciel externe
# coordonnées spatiales des échantillons
	mcq.write.tsv(pca, 'proteinpca.tsv')
# écriture des composantes (protéines)
	mcq.write.tsv(pca, 'proteinpca_comp.tsv', comp=T)

#visualisation des résultats de l'ACP (écrit dans un fichier pdf)
	mcqPlotProteinPCA(pca, colors='sample', pdf='acp.pdf')



################################# ANOVA, Heatmap et clustering sur les protéines

#ANOVA à 1 facteur
	anova <- mcq.protquantity.anova (qprot, 'sample')
# Visualisation de l'histogramme des pvalues de l'ANOVA
	mcq.plot.pvalue(anova, "sample") 
	mcq.plot.pvalue(anova, "sample", pdf="anova_hist_extraction.pdf") 
# 0.05 => seuil de signif sur le facteur "extraction"
	anova.signif <- mcq.select.anova.signif(anova, 0.05, factor='sample')
# Boxplot des protéines signif
	mcq.plot.protquantity.anova(anova.signif, pdf="prot_anova_signif.pdf")
# Ecriture des résultats de l'ANOVA dans un fichier :
# => totalité des résultats
	mcq.write.tsv(anova, 'anova.tsv')
# => uniquement les protéines signif
	mcq.write.tsv(anova.signif, 'anova_signif.tsv')

# on récupère la liste des protéines significatives déterminée par l'ANOVA
	protlist.signif <- mcq.get.protlist(anova.signif)
# on sélectionne les protéines quantifiées qui sont présentes dans la liste
	qprot.signif <- mcq.select.protlist(qprot, protlist.signif)

# on peut visualiser ces protéines sur un heatmap en fonction d'un facteur
	mcqPlotHeatmap(qprot.signif, factor="sample")
	mcqPlotHeatmapMeanRep(qprot.signif,factor="sample",'classification_by_conditions.pdf')

# Regroupement des protéines en clusters
	mcqPlotCluster(qprot.signif,factor="sample",nbclust=8,pdf='cluster.pdf')
	mcqPlotCluster(qprot.signif,factor="sample",nbclust=12,pdf='cluster_12.pdf')
	mcqPlotClusterMeanRep(qprot.signif,factor="sample", nbclust=8, pdf='cluster_by_conditions.pdf')
	mcqPlotClusterMeanRep(qprot.signif,factor="sample", nbclust=12, pdf='cluster_by_conditions_12.pdf')

