library("MassChroqR")
packageVersion("MassChroqR")

cat(paste(Sys.time(),"\n",sep =""))

dir.create("/tmp/test_MassChroqR", showWarnings = FALSE)

dir.create("/tmp/test_MassChroqR/test_get_dataframe", showWarnings = FALSE)

setwd ("/tmp/test_MassChroqR/test_get_dataframe")

cat("Test get dataframe")
cat("\n")   


if (file.exists("protpep.RData")) {
	load("protpep.RData")
} else {
	protPep <- mcq.read.protpep("/gorgone/pappso/formation/Novembre2016/TD/resultats_masschroq/XIC_result_prot.tsv", "/gorgone/pappso/formation/Novembre2016/TD/resultats_masschroq/XIC_result_pep.tsv")

	# import des metadata
	metadata <- mcq.read.metadata("/gorgone/pappso/formation/Novembre2016/TD/resultats_masschroq/metadata.ods")

	# Ajout des metadata à l'objet protPep
	protPep <- mcq.merge.metadata(protPep, metadata)
	save(protPep, file="protpep.RData")
}

cat("\n ")   
cat("df protPep\n")   
df=mcq.get.dataframe(protPep)
if (dim(df)[1]==230195){
	cat("\n")
	cat("#####################################\n")
	cat("      mcq.get.compar (protPep) nb peptiz x msrun = 230195  OK \n")
	cat("#####################################\n")
}else{
	cat("\n")
	cat("#####################################\n")
	cat("      ERROR mcq.get.compar (protPep) nb peptiz != 230195  \n")
	cat(dim(df)[1])
	cat("\n")
	cat("#####################################\n")
}

head(df)
mcq.write.tsv(protPep, file="df_protPep.tsv", comp=F)

peptidepca <- mcq.pca(protPep)
cat("\n")   
cat("df peptidepca\n")  
df=mcq.get.dataframe(peptidepca)
if (dim(df)[1]==19){
	cat("\n")
	cat("#####################################\n")
	cat("      mcq.get.compar (peptidepca) nb samples = 19  OK \n")
	cat("#####################################\n")
}else{
	cat("\n")
	cat("#####################################\n")
	cat("      ERROR mcq.get.compar (peptidepca) nb samples != 19  \n")
	cat(dim(df)[1])
	cat("\n")
	cat("#####################################\n")
}
head(df)
mcq.write.tsv(peptidepca, file="df_peptidepca.tsv", comp=F)
mcq.write.tsv(peptidepca, file="df_peptidepca_comp.tsv", comp=T)


cat("\n")   
cat("df pkcount\n")
pkcount <- mcq.peak.counting(protPep)
df=mcq.get.dataframe(pkcount)
if (dim(df)[1]==35321){
	cat("\n")
	cat("#####################################\n")
	cat("      mcq.get.compar (pkcount) nb prot x msrun = 35321  OK \n")
	cat("#####################################\n")
}else{
	cat("\n")
	cat("#####################################\n")
	cat("      ERROR mcq.get.compar (pkcount) nb peptiz != 35321  \n")
	cat(dim(df)[1])
	cat("\n")
	cat("#####################################\n")
}

head(df)
mcq.write.tsv(pkcount, file="df_pkcount.tsv", comp=F)


pkcount.anova = mcq.anova(pkcount, "extraction")
cat("\n")   
cat("df pkcount.anova\n") 
df=mcq.get.dataframe(pkcount.anova)
if (dim(df)[1]==35321){
	cat("\n")
	cat("#####################################\n")
	cat("      mcq.get.compar (pkcount.anova) nb prot x msrun = 35321  OK \n")
	cat("#####################################\n")
}else{
	cat("\n")
	cat("#####################################\n")
	cat("      ERROR mcq.get.compar (pkcount.anova) nb peptiz != 35321  \n")
	cat(dim(df)[1])
	cat("\n")
	cat("#####################################\n")
}

head(df)
mcq.write.tsv(pkcount.anova, file="df_pkcount.anova.tsv", comp=F)


qprot <- mcq.protquantity(protPep)
cat("\n")   
cat("df qprot\n")
df=mcq.get.dataframe(qprot)
if (dim(df)[1]==35248){
	cat("\n")
	cat("#####################################\n")
	cat("      mcq.get.compar (qprot) qprot x msrun = 35248  OK \n")
	cat("#####################################\n")
}else{
	cat("\n")
	cat("#####################################\n")
	cat("      ERROR mcq.get.compar (qprot) nb qprot x msrun != 35248  \n")
	cat(dim(df)[1])
	cat("\n")
	cat("#####################################\n")
}

head(df)
mcq.write.tsv(qprot, file="df_qprot.tsv", comp=F)


qprot.anova <- mcq.anova(qprot, 'extraction')
cat("\n")   
cat("df qprot.anova\n")
df=mcq.get.dataframe(qprot.anova)
if (dim(df)[1]==35248){
	cat("\n")
	cat("#####################################\n")
	cat("      mcq.get.compar (qprot.anova) qprot x msrun = 35248  OK \n")
	cat("#####################################\n")
}else{
	cat("\n")
	cat("#####################################\n")
	cat("      ERROR mcq.get.compar (qprot.anova) nb qprot x msrun != 35248  \n")
	cat(dim(df)[1])
	cat("\n")
	cat("#####################################\n")
}

head(df)
mcq.write.tsv(qprot.anova, file="df_qprot.anova.tsv", comp=F)


qprot.anova2F <- mcq.anova(qprot, c("extraction","rep"))
#str(qprot.anova2F) # montre anova2F ko NA pour toutes les pvalue (a verifier lorsque anova2F corrigee
cat("\n")   
cat("df qprot.anova2F\n")
if (dim(df)[1]==35248){
	cat("\n")
	cat("#####################################\n")
	cat("      mcq.get.compar (qprot.anova2F) qprot x msrun = 35248  OK \n")
	cat("#####################################\n")
}else{
	cat("\n")
	cat("#####################################\n")
	cat("      ERROR mcq.get.compar (qprot.anova2F) nb qprot x msrun != 35248  \n")
	cat(dim(df)[1])
	cat("\n")
	cat("#####################################\n")
}

head(df)
mcq.write.tsv(qprot.anova2F, file="df_qprot.anova2F.tsv", comp=F)


pca <- mcq.pca(qprot)
cat("\n")   
cat("df pca qprot\n")
df=mcq.get.dataframe(pca)
if (dim(df)[1]==19){
	cat("\n")
	cat("#####################################\n")
	cat("      mcq.get.compar (pca) nb samples = 19  OK \n")
	cat("#####################################\n")
}else{
	cat("\n")
	cat("#####################################\n")
	cat("      ERROR mcq.get.compar (pca) nb samples != 19  \n")
	cat(dim(df)[1])
	cat("\n")
	cat("#####################################\n")
}

head(df)
mcq.write.tsv(pca, file="df_pca_qprot.tsv", comp=F)
mcq.write.tsv(pca, file="df_pca_qprot_comp.tsv", comp=T)


protlist = mcq.get.protlist(qprot.anova)
cat("\n")   
cat("df protlist\n")   
df=mcq.get.dataframe(protlist)
if (dim(df)[1]==1859){
	cat("\n")
	cat("#####################################\n")
	cat("      mcq.get.compar (protlist) nb prot = 1859  OK \n")
	cat("#####################################\n")
}else{
	cat("\n")
	cat("#####################################\n")
	cat("      ERROR mcq.get.compar (protlist) nb prot != 1859  \n")
	cat(dim(df)[1])
	cat("\n")
	cat("#####################################\n")
}

head(df)
mcq.write.tsv(protlist, file="df_protlist.tsv", comp=F)


spectral.count = mcq.read.spectralcounting("/gorgone/pappso/formation/Novembre2016/TD/resultats_masschroq/results_compar_spectra.txt")
metadata <- mcq.read.metadata("/gorgone/pappso/formation/Novembre2016/TD/resultats_masschroq/metadata.ods")
spectral.count = mcq.merge.metadata(spectral.count, metadata)

cat("\n")   
cat("df spectral.count\n") 
df=mcq.get.dataframe(spectral.count)
if (dim(df)[1]==34048){
	cat("\n")
	cat("#####################################\n")
	cat("      mcq.get.compar (spectral.count) nb prot x msrun = 34048  OK \n")
	cat("#####################################\n")
}else{
	cat("\n")
	cat("#####################################\n")
	cat("      ERROR mcq.get.compar (spectral.count) nb peptiz != 34048  \n")
	cat(dim(df)[1])
	cat("\n")
	cat("#####################################\n")
}

head(df)
mcq.write.tsv(spectral.count, file="df_spectral.count.tsv", comp=F)

spectral.count.anova = mcq.anova(spectral.count, 'extraction')
cat("\n")   
cat("df spectral.count.anova\n") 
df=mcq.get.dataframe(spectral.count.anova)
if (dim(df)[1]==34048){
	cat("\n")
	cat("#####################################\n")
	cat("      mcq.get.compar (spectral.count.anova) nb prot x msrun = 34048  OK \n")
	cat("#####################################\n")
}else{
	cat("\n")
	cat("#####################################\n")
	cat("      ERROR mcq.get.compar (spectral.count.anova) nb peptiz != 34048  \n")
	cat(dim(df)[1])
	cat("\n")
	cat("#####################################\n")
}

head(df)
mcq.write.tsv(spectral.count.anova, file="df_spectral.count.anova.tsv", comp=F)


cat("###########################################\n")
cat("                Test get_dataframe OK                                                             \n ")
cat("              Verifiez fichiers dans /tmp                                                      \n")
cat("###########################################\n")



