
#**************************************************************************************************************************************************
#**************************************************************************************************************************************************
#******************************************************   Installation of MassChroqR
#**************************************************************************************************************************************************
#**************************************************************************************************************************************************

# See the file "lisezmoi.txt".

# Loading of the MassChroqR package
	library("MassChroqR")

# Checking of the version of the MassChroqR package
	packageVersion("MassChroqR")
	cat(paste(Sys.time(),"\n",sep =""))

# Change of the working directory (replace '/path/to/my_working_directory' by your computer tree).
	dir.create("/tmp/test_MassChroqR", showWarnings = FALSE)

	dir.create("/tmp/test_MassChroqR/test_lanceur_reference", showWarnings = FALSE)

	setwd ("/tmp/test_MassChroqR/test_lanceur_reference")




#**************************************************************************************************************************************************
#**************************************************************************************************************************************************
#******************************************************   Analysis on quantification data (peak counting and XIC)
#**************************************************************************************************************************************************
#**************************************************************************************************************************************************


#********************************************************
#--------------------------------------------------------
#             Loading of the data and metadata
#--------------------------------------------------------
#********************************************************


# Loading of MassChroq data. NB: peptide intensities measured as peak areas are automatically log10-transformed.
	protPep <- mcq.read.protpep("/gorgone/pappso/formation/Novembre2016/TD/resultats_masschroq/XIC_result_prot.tsv", "/gorgone/pappso/formation/Novembre2016/TD/resultats_masschroq/XIC_result_pep.tsv")

# Loading of Skyline data
	###!!!!! TO DO

# Overview of the content of the 'protPep' object
	summary (protPep)

# Export of a template for the metadata (either in .txt or .tsv which is equivalent to csv except that the text separator is a tab). The file is save in '/path/to/my_working_directory'.
	mcq.export.metadata.template(protPep, file="metadata.txt")

#!!!!!!!!!!!!!!!!!!!!! Open the template in Libreoffice or Excel and fill in the columns with all the information that you have about your samples (e.g. information relative to the experimental design such as the treatment, the replicate, the genotype, etc.). Save the file in an .ods format.!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

# Import of the metadata
	metadata.info <- mcq.read.metadata("/gorgone/pappso/formation/Novembre2016/TD/resultats_masschroq/metadata.ods")

# Attachment of the metadata to the 'protPep' object
	protPep <- mcq.merge.metadata(protPep, metadata=metadata.info)




#********************************************************
#--------------------------------------------------------
#             Checking of the quality of the data
#--------------------------------------------------------
#********************************************************


############# Checking of the distribution of the chromatographic peak width. Are there many peptides intensities measured on very large peaks?

# Display of the graph on the screen
	#mcq.plot.peak.width(protPep) 

# Export of the graph in a .pdf file in '/path/to/my_working_directory'			
	mcq.plot.peak.width(protPep, file="QUAL_distrib_peak_width.pdf") 	


#############  Checking of the variability of the peptide retention time (RT) by plotting the distribution of the standard deviation of RT. Are there many peptides showing huge variations of their RT?

# Display of graph on the screen. If necessary, it is possible to limit the range of the x axis (e.g. here, 40s).
	mcq.plot.rt.variability(protPep, limit=100, nclass=50) 

# Export of the graph in a .pdf file in '/path/to/my_working_directory									
	mcq.plot.rt.variability(protPep, limit=40, file="QUAL_distrib_rt_variability.pdf")  
	

#############  Check the number of peaks quantified in each sample. Are there samples with much fewer peaks?

# Counting of the number of 'peaks'
	pkcount <- mcq.peak.counting(protPep)

# Display of the graph on the screen
	#mcq.plot.counts.per.sample(pkcount)

# Export of the graph in a .pdf file in '/path/to/my_working_directory'	
	mcq.plot.counts.per.sample(pkcount,file="QUAL_peak_count_per_sample.pdf")


#############  Checking of the distribution of the peptide intensities in the samples. Are there samples showing odd distribution?

# Display of the graph on the screen
	#mcq.plot.global.intensity(protPep, factorToColor="rep")

# Export of the graph in a .pdf file in '/path/to/my_working_directory'	
	mcq.plot.global.intensity(protPep, factorToColor="rep", file="QUAL_boxplot.pdf")

#############  Checking of the average peptide intensity throughout the chromatography. Are there samples showing abnormal intensity profile?

# Display of the graph on the screen
	#mcq.plot.intensity.profile(protPep, factorToColor="extraction", RTinterval=250)

# Export of the graph in a .pdf file in '/path/to/my_working_directory'	
	mcq.plot.intensity.profile(protPep, factorToColor="extraction", RTinterval=250, file="QUAL_intensity_profile.pdf")

#############  Checking of the experiment by a principal component analysis (PCA). Is there any outlier ?

# Execution of PCA using all the samples as individuals
	peptidepca <- mcq.pca(protPep)	

# Execution of PCA using a factor or a combination of factors as individuals (in this case, average intensities are computed for the factor or for the combination of factors)
	#peptidepca <- mcq.pca(protPep, flist=c("extraction", "rep"))

# Display of the PCA on the screen. Possibility to modify the 'factorToColor' and 'labels' arguments to change the colors and the labels of the individuals represented on the PCA.				
	#mcq.plot.pca(peptidepca, factorToColor=c("extraction"), labels = c("extraction","rep"))

# Export of the PCA in a .pdf file in '/path/to/my_working_directory'	
	mcq.plot.pca(peptidepca, factorToColor=c("extraction","rep"), labels = c("extraction","rep"), file="QUAL_peptideACP.pdf")

# Export of the PCA results in '/path/to/my_working_directory'
	mcq.write.tsv(peptidepca, file="QUAL_peptidepca.tsv")


#############  If necessary, removal of dubious samples

# E.g. in the factor 'msrun', removal of the level 'sampb11'
	protPep_drop_samp <- mcq.drop(protPep, factor="msrun", levels="sampb11")

# Display of a summary of the 'protPep' object after removal of dubious samples
	summary(protPep)





#********************************************************
#--------------------------------------------------------
# Analysis by peak counting (semi-quantitative variations)
# A 'peak' is defined as a peptide-MH-charge
#--------------------------------------------------------
#********************************************************


#****************************************************************************************************************
# 1. Filtering of the data to remove peptides with dubious chromatographic data
#****************************************************************************************************************

# Removal of the peptides showing too much variations of their retention time because they may be derived from misidentification. Use the plot produced by the mcq.plot.rt.variability function to decide on the cut-off to use (e.g. here, 20 seconds)
	protPep <- mcq.drop.variable.rt(protPep, cutoff=20)

# Display of a summary of the 'protPep' object after removal of dubious peptides
	summary(protPep)



#****************************************************************************************************************
# 2. Counting of the number of 'peaks' which is used as a proxy for protein abundance
#****************************************************************************************************************

# Counting of the number of 'peaks'
	pkcount <- mcq.peak.counting(protPep)

# Export of the 'peak' counts for each protein in each sample in a 'compare' format in '/path/to/my_working_directory'
	mcq.write.compar.tsv(pkcount ,file="PK_compar.tsv", sampleid=F)



#****************************************************************************************************************
# 3. Analysis of the protein abundance variations
#****************************************************************************************************************

############# Differential analysis

# Removal of the proteins showing few abundance variations for a factor of interest 
	pkcount.mindiff <- mcq.select.mindiff(pkcount, mindiff=4, factor="extraction")

# ANOVA for the factors of interest. ANOVA is based on a generalized linear model using Poisson distribution. If there are several factors of interest, interaction term(s)  automatically included in the model.
	pkcount.anova <- mcq.anova(pkcount.mindiff, flist=c("extraction", "rep")) 

# Display the distribution of the p-values for the factor(s) declared in ANOVA on the screen
	#mcq.plot.pvalues(pkcount.anova, nclass=20) 

# Export the distribution of the p-values for the factor(s) declared in ANOVA in a .pdf file in '/path/to/my_working_directory'
	mcq.plot.pvalues(pkcount.anova, file="PK_hist_pvalues.pdf") 


############# Analysis of the proteins showing significant variations

# Selection of the proteins showing significant abundance variations for a given factor
	pkcount.anova.signif <- mcq.select.anova.signif(pkcount.anova, pvalue=0.05,factor="extraction")

# Retrieval of list of the proteins showing significant variations 
	protlist.signif = mcq.get.protlist(pkcount.anova.signif)

# Selection of the peak counts for the proteins in the list 
	pkprot.signif = mcq.select.protlist(pkcount, protlist=protlist.signif)


############# Plot of individual protein abundances

# Display of the graph on the screen for all the proteins
	#mcq.plot.proteins(pkcount.anova.signif) 

# Export of the graph in a .pdf file in '/path/to/my_working_directory'
	mcq.plot.proteins(pkcount.anova.signif, file="PK_plot_prot_signif.pdf")



#****************************************************************************************************************
# 4. Export of the results in '/path/to/my_working_directory'
#****************************************************************************************************************

# Export of the proteins abundances in a 'compare' format (one sample = one column)
	mcq.write.compar.tsv(pkcount, file="PK_all.tsv") 

# Export of the proteins showing sufficient abundance variations (> mindiff parameter) for a factor of interest 
	mcq.write.compar.tsv(pkcount.mindiff, file="PK_mindiff.tsv")

# Export of the ANOVA results (only p-values) in a 'compare' format (one sample = one column)
	mcq.write.compar.tsv(pkcount.anova, file="PK_anova_mindiff.tsv") 

# Export of the peak counts together with the ANOVA results
	mcq.write.merge.tsv(pkcount,pkcount.anova,file="PK_anova_all_info.tsv",sampleid=F) 

# Export of the peak counts together with the ANOVA results for the proteins showing significant variations
	mcq.write.merge.tsv(pkprot.signif,pkcount.anova.signif,file="PK_anova_signif_info.tsv",sampleid=F) 





#********************************************************
#--------------------------------------------------------
#       Analysis by XIC (quantitative variations)
#--------------------------------------------------------
#********************************************************


#****************************************************************************************************************
# 1. Filtering for peptides with dubious chromatographic data
#****************************************************************************************************************

# If not done before, removal of the peptides showing too much variations of their retention time because they may be derived from misidentification. Use the plot produced by the mcq.plot.rt.variability function to decide on the cut-off to use (e.g. here, 20 seconds).
	protPep <- mcq.drop.variable.rt(protPep, cutoff=20)
	test <- mcq.drop.variable.rt(protPep, cutoff=19)

#  Removal of the peptide intensities corresponding to peaks whose width is higher than a given cut-off. Use the plot produced by the mcq.plot.peak.width function to decide on the cut-off to use (e.g. here, 100 seconds)
	protPep <- mcq.drop.wide.peaks(protPep, cutoff=100)

# Display of a summary of the 'protPep' object after removal of dubious peptides
	summary(protPep)



#****************************************************************************************************************
# 2. Normalization of peptide intensities to take into account possible global quantitative variations between LC-MS runs
#****************************************************************************************************************

############# Checking of the distribution of the peptide log-intensities in each sample

# Display of the graph on the screen
	#mcq.plot.intensity.distribution(protPep, nclass=100) 

# Export of the graph in a .pdf file in '/path/to/my_working_directory'	
	mcq.plot.intensity.distribution(protPep, nclass=100, file="XIC_distrib_log_intensities.pdf") 


############# Checking of the distribution of the differences of peptide intensities between each sample and a sample chosen as reference

# Display of the graph on the screen
	#mcq.plot.intensity.differences(protPep, refSample="sampa0", nclass=100)

# Export of the graph in a .pdf file in '/path/to/my_working_directory'	
	mcq.plot.intensity.differences(protPep, refSample="sampa0", nclass=100, file="XIC_distrib_differences_log_intensities.pdf")


############# Checking the global correlation between the peptide intensities of one sample and the peptide intensities of a sample chosen as reference

# Display of the graph on the screen
	#mcq.plot.intensity.correlation(protPep, refSample="sampa0") 

# Export of the graph in a .pdf file in '/path/to/my_working_directory'
	mcq.plot.intensity.correlation(protPep, refSample="sampa0", file="XIC_correlation_intensities.pdf")


############# Normalization of the peptide intensities

# Normalisation by a median-based method ("median" or "median.RT", based on a reference sample) or by a "percent" method
	protPep <- mcq.normalize(protPep, refSample="sampa0", method="median")


############# Control of the effect of normalization

# Display of the graph of intensity distributions on the screen
	#mcq.plot.global.intensity(protPep, factorToColor="rep") 

# Export of the graph of intensity distributions in a .pdf file in '/path/to/my_working_directory'
	mcq.plot.global.intensity(protPep, factorToColor="rep", file="XIC_normalization_effect1.pdf")

# Display of the graph of intensity profile throughout LC on the screen
	#mcq.plot.intensity.profile(protPep, factorToColor="extraction", RTinterval=250)

# Export of the graph  of intensity profile throughout LC in a .pdf file in '/path/to/my_working_directory'	
	mcq.plot.intensity.profile(protPep, factorToColor="extraction", RTinterval=250, file="XIC_normalization_effect2.pdf")


#****************************************************************************************************************
# 3. Filtering for shared peptides and for peptides with dubious intensity data
#****************************************************************************************************************


############# Checking of the distribution of the number of proteins to which a peptide belongs. Remark : a peptide that belongs to only one protein in the dataset is not proteotypic to this protein. It is in fact specific of a subgroup of XTandempipeline
# Display of the graph on the screen
	#mcq.plot.peptide.sharing(protPep) 

# Export of the graph in a .pdf file in '/path/to/my_working_directory'
	mcq.plot.peptide.sharing(protPep, file = "XIC_shared_peptides.pdf")


############# Removal of shared peptides

	protPep <- mcq.drop.shared.peptides(protPep)

# Display of a summary of the 'protPep' object after removal of shared peptides
	summary(protPep)


############# Checking of the distribution of the number of samples in which a peptide-MH-charge is quantified

# Display of the graph on the screen
	#mcq.plot.peptide.reproducibility(protPep)

# Export of the graphe in a .pdf file in '/path/to/my_working_directory'
	mcq.plot.peptide.reproducibility(protPep, file="XIC_peptide_repeatability.pdf")


############# Remove peptides that are absent in more than a given proportion of the samples (here 5%)

	protPep <- mcq.drop.unreproducible.peptides(protPep, method="percent", percentCutoff=0.05) 

# Display of a summary of the 'protPep' object after removal of peptides that are absent in more than a given proportion of the samples
	summary(protPep)


############# Remove peptides whose intensity profile deviates from the average profile of the peptides from the same protein. This filter must be applied only if the number of levels within one of the factors of interest (factors like replicates not included) is superior or equal to 3 because it is based on the correlation between peptides belonging to the same protein.  

	protPep <- mcq.drop.uncorrelated.peptides(protPep, "extraction", min.corr=0.)


############# Remove proteins quantified by only one peptide. 

	protPep <- mcq.select.2pepbyprot(protPep)


############# Export of the filtered intensity data 

# Export in a compare 'format'(one sample = one column) in '/path/to/my_working_directory'
	mcq.write.compar.tsv(protPep, file="XIC_protPep_filtered.tsv")


#****************************************************************************************************************
# 4. Imputation of missing peptide intensities
#****************************************************************************************************************

# Imputation of missing peptide intensities. No imputation is made for peptide intensity when a protein completely absent from a sample.
	protPepnona <- mcq.impute(protPep)

# Export of the imputed intensity data in a compare 'format'(one sample = one column) in '/path/to/my_working_directory'
	mcq.write.compar.tsv(protPepnona, file="XIC_protPep_filtered_imputed_compar.tsv")



#****************************************************************************************************************
# 5. Computation of protein abundances
#****************************************************************************************************************

############# Computation of the protein abundances

# Computation of the protein abundances as the sum of the peptide intensities
	qprot <- mcq.protquantity(protPepnona)

# Creation of a table containing the protein abundances in a 'compare' format (one sample = one column)
	prot.abundances <- mcq.get.compar(qprot)

# Display of the first lines of the prot.abundances table
	head(prot.abundances)



############# Export of the protein abundances in '/path/to/my_working_directory'

# Export in a compare 'format' (one sample = one column)
	mcq.write.compar.tsv(qprot, file="XIC_prot_abundances_compar.tsv")



#****************************************************************************************************************
# 6. Imputation of missing protein abundances
#****************************************************************************************************************

############# Imputation of missing protein abundance by the minimum abundance obtained for this protein in the whole experiment. 

	qprot <- mcq.replace.na.protein.value.by.min(qprot)


############# Export of imputed protein abundances in '/path/to/my_working_directory'

# Export in a compare 'format' (one sample = one column)
	mcq.write.compar.tsv(qprot, file="XIC_prot_abundances_imputed_compar.tsv")


#****************************************************************************************************************
# 7. Overview of the protein abundance data
#****************************************************************************************************************

############# Plotting the distribution of the standard deviation of the protein abundance. This plot gives an idea of the variability of the proteins.

# Display of the graph on the screen
	#mcq.plot.protein.value.sd(qprot)

# Export of the graph in a .pdf file in '/path/to/my_working_directory'
	mcq.plot.protein.value.sd(qprot, file="XIC_distrib_abundance_variability.pdf")


#############  PCA representation

# Execution of PCA using all the samples as individuals
	protpca <- mcq.pca(qprot)

# Execution of PCA using a factor or a combination of factors as individuals (in this case, average intensities are computed for the factor or for the combination of factors)
	protpca <- mcq.pca(qprot, flist=c("extraction","rep"))

# Display of the PCA on the screen. Possibility to modify the 'factorToColor' and 'labels' arguments to change the colors and the labels of the individuals represented on the PCA.				
	#mcq.plot.pca(protpca, factorToColor=c("extraction"), labels = c("extraction","rep"))

# Export of the PCA in a .pdf file in '/path/to/my_working_directory'	
	mcq.plot.pca(protpca, factorToColor=c("extraction"), labels = c("extraction","rep"), file="XIC_protein_PCA.pdf")

# Export of the individual coordinates in '/path/to/my_working_directory'
	mcq.write.tsv(protpca, file="XIC_protein_pca.tsv")

# Export of the variable components in '/path/to/my_working_directory'
	mcq.write.tsv(protpca, file="XIC_protein_pca_comp.tsv", comp=T)


############# Plotting a heatmap

# Display of the graph on the screen. Possibility to change the method of aggregation ('method' argument) and the method to compute the distances ('distfun' argument).
	#mcq.plot.heatmap(qprot, flist=c("extraction", "rep"), factorToColor="extraction")

# Export of the graph in a .pdf file in '/path/to/my_working_directory'
	mcq.plot.heatmap(qprot, flist=c("extraction", "rep"), factorToColor="extraction", file="XIC_heatmap.pdf")


############# Clustering of the proteins

# Display of the graph on the screen
	#mcq.plot.cluster(qprot, flist="extraction", nbclust=8)

# Export of the graph in a .pdf file in '/path/to/my_working_directory'
	#mcq.plot.cluster(qprot, flist="extraction", nbclust=8, file="XIC_cluster.pdf")

# Export of the graph in a .pdf file and the results in .txt or .tsv which is equivalent to csv except that the text separator is a tab. The files are saved in '/path/to/my_working_directory'
	mcq.plot.cluster(qprot, flist="extraction", nbclust=8, file="XIC_cluster.pdf", outputfile="XIC_result_cluster.tsv")



#****************************************************************************************************************
# 8. Analysis of protein abundance variations
#****************************************************************************************************************

#############  Removal of proteins showing little variation of abundance. Use the plot produced by the mcq.plot.protein.value.sd function to decide on the cut-off to use (e.g. here, proteins for which the absolute value of standard deviation of abundance is lower than 0.05 are removed)

	qprot <- mcq.drop.protquantity.sd(qprot,cutoff=0.05)

############# Differential analysis 

# ANOVA for the factors of interest
	anova <- mcq.anova (qprot, flist=c("extraction"))

# Display the distribution of the p-values for a factor of interest on the screen
	#mcq.plot.pvalues(anova) 

# Export the distribution of the p-values for a factor of interest in a .pdf file in '/path/to/my_working_directory'
	mcq.plot.pvalues(anova, file="XIC_hist_pvalues.pdf") 


############# Analysis of the proteins showing significant variations

# Selection of the proteins showing significant abundance variations for a given factor
	anova.signif <- mcq.select.anova.signif(anova, 0.01, factor="extraction")

# Retrieval of list of the proteins showing significant variations 
	protlist.signif <- mcq.get.protlist(anova.signif)

# Selection of the abundances for the proteins in the list 
	qprot.signif <- mcq.select.protlist(qprot, protlist.signif)


############# Plot of individual protein abundances

# Display of the graph on the screen for all the proteins
	#mcq.plot.proteins(anova.signif)

# Export of the graph in a .pdf file in '/path/to/my_working_directory'
	mcq.plot.proteins(anova.signif, file="XIC_plot_prot_signif.pdf")


############# Plot of the protein abundance ratios

# Display of the graph on the screen
	#mcq.plot.ratio(qprot.signif,factor="extraction", numerator="teal", denominator="urnb")

# Export of the graph in a .pdf file in '/path/to/my_working_directory'
	#mcq.plot.ratio(qprot.signif,factor="extraction", numerator="teal", denominator="urnb", file="XIC_Ratio_signif.pdf")

# Export of the graph in a .pdf file and the ratios in .txt or .tsv which is equivalent to csv except that the text separator is a tab. The files are saved in '/path/to/my_working_directory'
	mcq.plot.ratio(qprot.signif,factor="extraction", numerator="teal", denominator="urnb", file="XIC_ratio_signif.pdf", outputfile="XIC_ratio_signif.tsv")



#****************************************************************************************************************
# 9. Export of the results in '/path/to/my_working_directory'
#****************************************************************************************************************

# Export of the proteins quantities in a 'compare' format (one sample = one column)
	mcq.write.compar.tsv(qprot, file="XIC_all.tsv")

# Export of the ANOVA results (only p-values) in a 'compare' format (one sample = one column)
	mcq.write.compar.tsv(anova, file="XIC_anova.tsv")

# Export of the proteins quantities together with the ANOVA results
	mcq.write.merge.tsv(qprot,anova, file="XIC_anova_all_info.tsv",sampleid=F)

# Export of the protein abundances together with the ANOVA results for the proteins showing significant variations
	mcq.write.merge.tsv(qprot.signif, anova.signif,file="XIC_anova_signif_info.tsv", sampleid=F)






#**************************************************************************************************************************************************
#**************************************************************************************************************************************************
#******************************************************   Analysis on identification data (spectral counting)
#**************************************************************************************************************************************************
#**************************************************************************************************************************************************


#****************************************************************************************************************
# 1. Loading of the data
#****************************************************************************************************************


##!!!!!!!!!!!!!!!!!!!!! The inputfile containing spectral count data must be in .txt format. To this end, export "Peptide, protein and compar results as spreadsheet" in "Tabulated text" from XtandemPipeline. XtandemPipeline will automatically produce a file named 'myresults_compar_spectra.txt'.!!!!!!!!!!!!!!!!!!!!!!!!!!!!

# Loading of the data
	spectral.count = mcq.read.spectralcounting("/gorgone/pappso/formation/Novembre2016/TD/resultats_masschroq/results_compar_spectra.txt")

# Export of a template for the metadata (either in .txt or .tsv which is equivalent to csv except that the text separator is a tab). The file is save in '/path/to/my_working_directory'.
	mcq.export.metadata.template(spectral.count, file="metadata.txt")

#!!!!!!!!!!!!!!!!!!!!! Open the template in Libreoffice or Excel and fill in the columns with all the information that you have about your samples (e.g. information relative to the experimental design such as the treatment, the replicate, the genotype, etc.). Save the file in an .ods format.!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

# Import of the metadata.
	metadata.info <- mcq.read.metadata("/gorgone/pappso/formation/Novembre2016/TD/resultats_masschroq/metadata.ods")

# Attachment of the metadata to the 'spectral.count' object
	spectral.count <- mcq.merge.metadata(spectral.count, metadata.info)

# Overview of the content of the 'spectral.count' object
	summary (spectral.count)




#****************************************************************************************************************
# 2. Checking of the quality of the data
#****************************************************************************************************************

############# Checking of the total number of spectra for each sample 	

# Display of the graph on the screen
	#mcq.plot.counts.per.sample(spectral.count)

# Export of the graph in a .pdf file in '/path/to/my_working_directory'
	mcq.plot.counts.per.sample(spectral.count,file="SC_count_per_sample.pdf")


#############  Checking of the experiment by a principal component analysis (PCA). Is there any outlier ?

# Execution of PCA using all the samples as individuals
	sc.pca <- mcq.pca(spectral.count)	

# Execution of PCA using a factor or a combination of factors as individuals (in this case, average intensities are computed for the factor or for the combination of factors)
	#sc.pca <- mcq.pca(spectral.count, flist=c("extraction", "rep"))

# Display of the PCA on the screen. Possibility to modify the 'factorToColor' and 'labels' arguments to change the colors and the labels of the individuals represented on the PCA.				
	#mcq.plot.pca(sc.pca, factorToColor=c("extraction"), labels = c("extraction","rep"))

# Export of the PCA in a .pdf file in '/path/to/my_working_directory'	
	mcq.plot.pca(sc.pca, factorToColor=c("extraction","rep"), labels = c("extraction","rep"), file="SC_PCA.pdf")

# Export of the PCA results in '/path/to/my_working_directory'
	mcq.write.tsv(sc.pca, file="SC_pca.tsv")


#############  If necessary, removal of dubious samples

# E.g. in the factor 'msrun', removal of the level 'samp11'
	spectral.count.drop.samp <- mcq.drop(spectral.count, factor="msrun", levels="sampb11")

# Display of a summary of the 'protPep' object after removal of dubious samples
	summary(spectral.count.drop.samp)





#****************************************************************************************************************
# 3. Overview of the protein abundance data
#****************************************************************************************************************


############# Plotting a heatmap

# Display of the graph on the screen. Possibility to change the method of aggregation ('method' argument) and the method to compute the distances ('distfun' argument).
	#mcq.plot.heatmap(spectral.count, flist=c("extraction", "rep"), factorToColor="extraction")

# Export of the graph in a .pdf file in '/path/to/my_working_directory'
	mcq.plot.heatmap(spectral.count, flist=c("extraction", "rep"), factorToColor="extraction", file="SC_heatmap.pdf")


############# Clustering of the proteins

# Display of the graph on the screen
	#mcq.plot.cluster(spectral.count, flist="extraction", nbclust=8)

# Export of the graph in a .pdf file in '/path/to/my_working_directory'
	#mcq.plot.cluster(spectral.count, flist="extraction", nbclust=8, file="SC_cluster.pdf")

# Export of the graph in a .pdf file and the results in a .txt or .csv file in '/path/to/my_working_directory'
	mcq.plot.cluster(spectral.count, flist="extraction", nbclust=8, file="SC_cluster.pdf", outputfile="SC_result_cluster.txt")




#****************************************************************************************************************
# 4. Analysis of protein abundance variations
#****************************************************************************************************************

#############  Removal of proteins showing little variation in their number of spectra (differences less than a given cut-off (here, 5) are considered as noise)

	spectral.count.mindiff =  mcq.select.mindiff(spectral.count, 5, "extraction")


############# Differential analysis 

# ANOVA for the factors of interest
	spectral.count.anova <- mcq.anova(spectral.count.mindiff,"extraction")

# Display the distribution of the p-values for a factor of interest on the screen
	#mcq.plot.pvalues(spectral.count.anova) 

# Export the distribution of the p-values for a factor of interest in a .pdf file in '/path/to/my_working_directory'
	mcq.plot.pvalues(spectral.count.anova, file="SC_hist_pvalues.pdf") 


############# Analysis of the proteins showing significant variations

# Selection of the proteins showing significant abundance variations for a given factor
	spectral.count.anova.signif <- mcq.select.anova.signif(spectral.count.anova, 0.01, factor="extraction")

# Retrieval of list of the proteins showing significant variations 
	protlist.signif <- mcq.get.protlist(spectral.count.anova.signif)

# Selection of the spectral counts for the proteins in the list 
	spectralprot.signif = mcq.select.protlist(spectral.count, protlist.signif)



############# Plot of individual protein abundances

# Display of the graph on the screen for all the proteins
	#mcq.plot.proteins(spectral.count.anova.signif)

# Export of the graph in a .pdf file in '/path/to/my_working_directory'
	mcq.plot.proteins(spectral.count.anova.signif, file="SC_plot_prot_signif.pdf")



#****************************************************************************************************************
# 5. Export of the results in '/path/to/my_working_directory'
#****************************************************************************************************************

# Export of the spectral counting in a 'compare' format (one sample = one column)
	mcq.write.compar.tsv(spectral.count,file="SC_all.tsv",sampleid=F)
	
# Export of the proteins showing sufficient abundance variations (> mindiff parameter) for a factor of interest 
	mcq.write.compar.tsv(spectral.count.mindiff, file="SC_mindiff.tsv")

# Export of the ANOVA results (only p-values) in a 'compare' format (one sample = one column)
	mcq.write.compar.tsv(spectral.count.anova, file="SC_anova_mindiff.tsv")

# Export of the spectral counts together with the ANOVA results
	mcq.write.merge.tsv(spectral.count,spectral.count.anova,file="SC_anova_all_info.tsv",sampleid=F)

# Export of the peak counts together with the ANOVA results for the proteins showing significant variations
	mcq.write.merge.tsv(spectralprot.signif,spectral.count.anova.signif,file="SC_anova_signif_info.tsv",sampleid=F)



#**************************************************************************************************************************************************
#**************************************************************************************************************************************************
#******************************************************   Export of a synthesis
#**************************************************************************************************************************************************
#**************************************************************************************************************************************************

# Export of a synthesis table containing the results of spectral counting analysis, peak counting analysis and XIC analysis
	mcq.write.synthesis.tsv(spectral.count,spectral.count.anova,pkcount,pkcount.anova,qprot,anova,file="Synthesis_tab.tsv")














