library("MassChroqR")
packageVersion("MassChroqR")
cat(paste(Sys.time(),"\n",sep =""))

dir.create("/tmp/test_MassChroqR", showWarnings = FALSE)

dir.create("/tmp/test_MassChroqR/test_mcq_anova", showWarnings = FALSE)

setwd ("/tmp/test_MassChroqR/test_mcq_anova")

cat("Test mcq anova\n")

if (file.exists("protpep.RData")) {
	load("protpep.RData")
} else {
	protPep <- mcq.read.protpep("/gorgone/pappso/formation/Novembre2016/TD/resultats_masschroq/XIC_result_prot.tsv", "/gorgone/pappso/formation/Novembre2016/TD/resultats_masschroq/XIC_result_pep.tsv")

	# import des métadata
	metadata <- mcq.read.metadata("/gorgone/pappso/formation/Novembre2016/TD/resultats_masschroq/metadata.ods")

	# Ajout des métadata à l'objet protPep
	protPep <- mcq.merge.metadata(protPep, metadata)
	save(protPep, file="protpep.RData")
}

# test incorrect object (protPep)
result <- tryCatch({

			mcq.anova(protPep)

		}, warning = function(war) {

			# warning handler picks up where error was generated
			print(paste("MY_WARNING:  ",war))
			return()

		}, error = function(err) {

			# error handler picks up where error was generated
			print(paste("MY_ERROR:  ",err))

			cat ("*********************************************\n")
			cat (" error message expected OK\n")
			cat ("*********************************************\n")

			return()

		})



cat("###################################\n")
cat("      test glm peakcounting                                              \n")
cat("###################################\n")

cat("\n")
cat("#####################################\n")
cat("PC => model glm 1 factor\n")   
cat("#####################################\n")


if (file.exists("pkcount.RData")) {
	load("pkcount.RData")
} else {
	pkcount <- mcq.peak.counting(protPep)
	save(pkcount, file="pkcount.RData")
}

if (file.exists("pkcount.glm.RData")) {
	load("pkcount.glm.RData")
} else {
	pkcount.glm = mcq.anova(pkcount, flist="extraction")
	save(pkcount.glm, file="pkcount.glm.RData")
}

# Visualisation de l'histogramme des pvalues
mcq.plot.pvalues(pkcount.glm, file="pkcount_model_glm_1F_pvalues.pdf") 

# Créer un tableau contenant le counting de peak par protéines et les résultats de l'ANOVA
dfpkcountglm <- mcq.get.dataframe(pkcount.glm)
# Affichage des premières lignes du dataframe obtenu
cat("\n")
cat("head dfpkcountglm 1 factor\n")   
head(dfpkcountglm)

# Exporter les résultats au format csv
mcq.write.compar.tsv(pkcount.glm, "pkcount_model_glm_1F.tsv")

cat("\n")
cat("#####################################\n")
cat("PC => model glm 2 factors\n")   
cat("#####################################\n")

if (file.exists("pkcount.glm2F.RData")) {
	load("pkcount.glm2F.RData")
} else {
	pkcount.glm = mcq.anova(pkcount, flist=c("extraction","rep"))
	save(pkcount.glm, file="pkcount.glm2F.RData")
}

# Créer un tableau contenant le counting de peak par protéines et les résultats de l'ANOVA
dfpkcountglm <- mcq.get.dataframe(pkcount.glm)
#WARNING : There is Not valid models in your tab, verify your individuals data quality
cat("\n")
cat("head dfpkcountglm 2 factors\n")   

# Affichage des premières lignes du dataframe obtenu
head(dfpkcountglm)

# Exporter les résultats au format csv
mcq.write.compar.tsv(pkcount.glm, "pkcount_model_glm_2F.tsv")
#WARNING : There is Not valid models in your tab, verify your individuals data quality

# pvalue => seuil de pvalue
pkcount.glm.signif <- mcq.select.anova.signif(pkcount.glm, pvalue=0.01,factor="extraction")
#4 proteins selected. 1855 proteins dropped

# Boxplot des protéines signif en fonction du facteur choisi
# (par défaut, c'est le facteur utilisé dans l'ANOVA qui sera pris en compte)
mcq.plot.proteins(pkcount.glm.signif, file="pkcount_model_glm_2F_plot_signif.pdf")

# Représentation de résultats (Heatmap)
mcq.plot.heatmap(pkcount.glm.signif, flist="extraction",file="pkcount_model_glm_2F_Heatmap_signif.pdf",cexRow=0.5)


#stop ('arret test')

cat("###################################\n")
cat("      test glm peakcounting     OK                                     \n")
cat("###################################\n")


cat("###################################\n")
cat("      test aov XIC                                                               \n")
cat("###################################\n")

cat("\n")
cat("XIC => model aov 1 factor\n")   


if (file.exists("qprot.RData")) {
	load("qprot.RData")
} else {
	qprot <- mcq.protquantity(protPep)
	save(qprot, file="qprot.RData")
}
	
if (file.exists("qprot.aov.RData")) {
	load("qprot.aov.RData")
} else {
	# nouvelle fonction anova modele aov 
	qprot.aov <- mcq.anova(qprot, "extraction")
	save(qprot.aov, file="qprot.aov.RData")
}

# Visualisation de l'histogramme des pvalues
mcq.plot.pvalues(qprot.aov, file="XIC_model_aov_pvalues.pdf") 

# Exporter les résultats au format csv
mcq.write.compar.tsv(qprot.aov, "XIC_model_aov1F.tsv")

# Représentation de résultats (Heatmap)
mcq.plot.heatmap(qprot.aov, flist=c("extraction","rep"),file="XIC_model_aov1F_Heatmap.pdf")

# pvalue => seuil de pvalue
qprot.aov.signif <- mcq.select.anova.signif(qprot.aov, pvalue=0.01,factor="extraction")

# Boxplot des protéines signif en fonction du facteur choisi
# (par défaut, c'est le facteur utilisé dans l'ANOVA qui sera pris en compte)
mcq.plot.proteins(qprot.aov.signif, file="XIC_model_aov1F_plot_signif.pdf")


# Représentation de résultats (Heatmap)
mcq.plot.heatmap(qprot.aov.signif, flist="extraction",file="XIC_model_aov1F_Heatmap_signif.pdf")

cat("\n")
cat("XIC => model aov 2 factors\n")   

# A VOIR ANOVA 2 F toutes les pvalues à NA
# anova 2F
if (file.exists("qprot.aov2F.RData")) {
	load("qprot.aov2F.RData")
} else {
	qprot.aov2F <- mcq.anova(qprot, c("extraction","rep"))
	#There were 50 or more warnings (use warnings() to see the first 50)
	save(qprot.aov2F, file="qprot.aov2F.RData")
}


# Exporter les résultats au format csv
mcq.write.compar.tsv(qprot.aov2F, "XIC_model_aov2F.tsv")

cat("\n")
cat("XIC => model aov 1 factor with Tukey\n")   

if (file.exists("qprot.aov.Tukey.RData")) {
	load("qprot.aov.Tukey.RData")
} else {
	qprot.aov.Tukey <- mcq.anova(qprot, flist="extraction",Tukey="extraction")
	save(qprot.aov.Tukey, file="qprot.aov.Tukey.RData")
}

# plot de Tukey
# ATTENTION très long : sélectionner qq protéines

plist = mcq.protlist(c("GRMZM2G473001_P01 P51059 Phosphoenolpyruvate carboxylase 2 (PEPCase 2)(PEPC 2)(EC 4.1.1.31) seq=translation; coord=7:86433388..86439128:-1; parent_transcript=GRMZM2G473001_T01; parent_gene=GRMZM2G473001"
		,"GRMZM2G069542_P01 NP_001105503 phosphoenolpyruvate carboxylase seq=translation; coord=5:144808460..144816059:-1; parent_transcript=GRMZM2G069542_T01; parent_gene=GRMZM2G069542"
		,"GRMZM2G083841_P01 P04711 Phosphoenolpyruvate carboxylase 1 (PEPCase 1)(PEPC 1)(EC 4.1.1.31) seq=translation; coord=9:61296279..61301686:1; parent_transcript=GRMZM2G083841_T01; parent_gene=GRMZM2G083841"
		,"GRMZM2G021331_P01 NP_001151807 ATP synthase beta chain seq=translation; coord=8:65969534..65973268:1; parent_transcript=GRMZM2G021331_T01; parent_gene=GRMZM2G021331"
		,"GRMZM2G113408_P01 P19023 ATP synthase subunit beta, mitochondrial Precursor (EC 3.6.3.14) seq=translation; coord=6:162937179..162940714:-1; parent_transcript=GRMZM2G113408_T01; parent_gene=GRMZM2G113408"
		,"GRMZM2G041275_P01 seq=translation; coord=3:207616747..207621242:-1; parent_transcript=GRMZM2G041275_T01; parent_gene=GRMZM2G041275"
		))

mcq.plot.Tukey(qprot.aov.Tukey,file="Tukey.pdf",protlist=plist)

# Exporter les résultats au format csv
mcq.write.compar.tsv(qprot.aov.Tukey, "XIC_model_aov1F_Tukey.tsv")

cat("\n")
cat("XIC => model aov 2 factors with Tukey\n")   

if (file.exists("qprot.aov2F.Tukey.RData")) {
	load("qprot.aov2F.Tukey.RData")
} else {
	qprot.aov2F.Tukey <- mcq.anova(qprot, flist=c("extraction","rep"),Tukey="extraction")
	save(qprot.aov2F.Tukey, file="qprot.aov2F.Tukey.RData")
}

# Exporter les résultats au format csv
mcq.write.compar.tsv(qprot.aov.Tukey, "XIC_model_aov2F_Tukey.tsv")


cat("###################################\n")
cat("      test aov XIC      OK                                                     \n")
cat("###################################\n")


cat("###################################\n")
cat("      test glm spectralcounting                                         \n")
cat("###################################\n")
cat("\n")
cat("SC => model glm 1 factor\n")   

if (file.exists("spectral.count.RData")) {
	load("spectral.count.RData")
} else {
	spectral.count = mcq.read.spectralcounting("/gorgone/pappso/formation/Novembre2016/TD/resultats_masschroq/results_compar_spectra.txt")
	metadata <- mcq.read.metadata("/gorgone/pappso/formation/Novembre2016/TD/resultats_masschroq/metadata.ods")
	spectral.count = mcq.merge.metadata(spectral.count, metadata)
	save(spectral.count, file="spectral.count.RData")
}

if (file.exists("spectral.count.glm.RData")) {
	load("spectral.count.glm.RData")
} else {
	spectral.count.glm = mcq.anova(spectral.count, "extraction")
	save(spectral.count.glm, file="spectral.count.glm.RData")
}


# Visualisation de l'histogramme des pvalues
mcq.plot.pvalues(spectral.count.glm, file="sccount_model_glm_1F_pvalues.pdf") 


# Exporter les résultats au format csv
mcq.write.compar.tsv(spectral.count.glm, "sccount_model_glm_1F_tab.tsv")

# Exporter les résultats au format csv
mcq.write.tsv(spectral.count.glm, "sccount_model_glm_1F_line.tsv")

cat("\n")
cat("SC => model glm 2 factors\n")   

if (file.exists("spectral.count.glm2F.RData")) {
	load("spectral.count.glm2F.RData")
} else {
	spectral.count.glm2F = mcq.anova(spectral.count, c("extraction","rep"))
	save(spectral.count.glm2F, file="spectral.count.glm2F.RData")
}

# Exporter les résultats au format csv
mcq.write.compar.tsv(spectral.count.glm, "sccount_model_glm_2F_tab.tsv")

# Exporter les résultats au format csv
mcq.write.tsv(spectral.count.glm, "sccount_model_glm_2F_line.tsv")

# Représentation de résultats (Heatmap)
mcq.plot.heatmap(spectral.count.glm, flist="extraction",file="sccount_model_glm_2F_Heatmap.pdf")

# pvalue => seuil de pvalue
spectral.count.glm.signif <- mcq.select.anova.signif(spectral.count.glm, pvalue=0.01,factor="extraction")

# Boxplot des protéines signif en fonction du facteur choisi
# (par défaut, c'est le facteur utilisé dans l'ANOVA qui sera pris en compte)
mcq.plot.proteins(spectral.count.glm.signif, file="sccount_model_glm_2F_plot_signif.pdf")

# Représentation de résultats (Heatmap)
mcq.plot.heatmap(spectral.count.glm.signif, flist="extraction",file="sccount_model_glm_2F_Heatmap_signif.pdf",cexRow=0.3)

cat("###################################\n")
cat("      test glm spectralcounting     OK                                \n")
cat("###################################\n")




cat("\n")
cat("##################################\n")
cat("      ALL TESTS   Model     OK   => cf pdf file                   \n")
cat("              Verifiez fichiers dans /tmp                                \n")
cat("##################################\n")

