library("MassChroqR")
packageVersion("MassChroqR")

dir.create("/tmp/test_MassChroqR",showWarnings = FALSE)

dir.create("/tmp/test_MassChroqR/test_mcq_ratio",showWarnings = FALSE)

setwd ("/tmp/test_MassChroqR/test_mcq_ratio")

cat("*********************************************\n")
cat("Test mcq get ratio\n")
cat("*********************************************\n")


if (file.exists("protpep.RData")) {
	load("protpep.RData")
} else {
	protPep <- mcq.read.protpep("/gorgone/pappso/formation/Novembre2016/TD/resultats_masschroq/XIC_result_prot.tsv", "/gorgone/pappso/formation/Novembre2016/TD/resultats_masschroq/XIC_result_pep.tsv")

	# import des métadata
	metadata <- mcq.read.metadata("/gorgone/pappso/formation/Novembre2016/TD/resultats_masschroq/metadata.ods")

	# Ajout des métadata à l'objet protPep
	protPep <- mcq.merge.metadata(protPep, metadata)
	save(protPep, file="protpep.RData")
}

# test bad object

result <- tryCatch({

			ratio = mcq.get.ratio(protPep, "tca1", "teal");
			
		}, warning = function(war) {

			# warning handler picks up where error was generated
			cat(paste("MY_WARNING:  ",war))
			return()

		}, error = function(err) {

			# error handler picks up where error was generated
			cat(paste("MY_ERROR:  ",err))

			cat("#####################################\n")
			cat (" error message expected OK\n")
			cat("#####################################\n")

			return()

		})


if (file.exists("protq.RData")) {
	load("protq.RData")
} else {
	qprot <- mcq.protquantity(protPep)
	save(qprot, file="protq.RData")
}

if (file.exists("ttest.RData")) {
	load("ttest.RData")
} else {
	ttest <- mcq.pairwise.t.test(qprot, "extraction")
	save(ttest, file="ttest.RData")
}

# test bad sample
result <- tryCatch({

			ratio = mcq.get.ratio(ttest, "badsample", "tca1");

		}, warning = function(war) {

			# warning handler picks up where error was generated
			cat(paste("MY_WARNING:  ",war))
			return()

		}, error = function(err) {

			# error handler picks up where error was generated
			cat(paste("MY_ERROR:  ",err))

			cat("#####################################\n")
			cat (" error message expected OK\n")
			cat("#####################################\n")

			return()

		})

# test no sample defined
result <- tryCatch({

			ratio = mcq.get.ratio(ttest)

		}, warning = function(war) {

			# warning handler picks up where error was generated
			cat(paste("MY_WARNING:  ",war))
			return()

		}, error = function(err) {

			# error handler picks up where error was generated
			cat(paste("MY_ERROR:  ",err))

			cat("#####################################\n")
			cat (" error message expected OK\n")
			cat("#####################################\n")

			return()

		})


# NB  test a reporter dans test_pairwise_test_prot.R à renommer en test_mcq_pairwise_t_test
if(dim(ttest@restest$pair.result)[1]==10752){
	cat("\n")
	cat("#####################################\n")
	cat("      Nb of pair.result =  10752 \n")
	cat(" 		mcq.pairwise T test is OK\n")
	cat("#####################################\n")

}else{
	cat("\n")
	cat("#####################################\n")
	cat("      ERROR Nb of pair.result !=  10752  \n")
	cat(dim(ttest@restest$pair.result)[1])
	cat("\n")
	cat(" 		mcq.pairwise T test is KO\n")
	cat("#####################################\n")
}

if(dim(ttest@restest$pair.result)[2]==6){
	cat("\n")
	cat("#####################################\n")
	cat("      Nb of variables =  6 \n")
	cat(" 		mcq.pairwise T test is OK\n")
	cat("#####################################\n")

}else{
	cat("\n")
	cat("#####################################\n")
	cat("      ERROR Nb of variables !=  6  \n")
	cat(dim(ttest@restest$pair.result)[1])
	cat("\n")
	cat(" 		mcq.pairwise T test is KO\n")
	cat("#####################################\n")
}

cat("inv=F\n" )
ratio = mcq.get.ratio(ttest, "tca1", "teal")
cat("summary ratio\n")
summary(ratio)

if(dim(ratio)[1]==1792){
	cat("\n")
	cat("#####################################\n")
	cat("      Nb of proteins =  1792 \n")
	cat(" 		mcq.get.ratio is OK\n")
	cat("#####################################\n")

}else{
	cat("\n")
	cat("#####################################\n")
	cat("      ERROR Nb of proteins !=  1792  \n")
	cat(dim(ratio)[1])
	cat("\n")
	cat(" 		mcq.get.ratio is KO\n")
	cat("#####################################\n")
}

if(dim(ratio)[2]==7){
	cat("\n")
	cat("#####################################\n")
	cat("      Nb of variables =  7 \n")
	cat(" 		mcq.get.ratio is OK\n")
	cat("#####################################\n")

}else{
	cat("\n")
	cat("#####################################\n")
	cat("      ERROR Nb of variables !=  7  \n")
	cat(dim(ratio)[1])
	cat("\n")
	cat(" 		mcq.get.ratio is KO\n")
	cat("#####################################\n")
}


cat("\n")   
cat("inv=T\n")
ratio = mcq.get.ratio(ttest, "teal", "tca1");
cat("summary ratio\n")
summary(ratio)

if(dim(ratio)[1]==1792){
	cat("\n")
	cat("#####################################\n")
	cat("      Nb of proteins =  1792 \n")
	cat(" 		mcq.get.ratio is OK\n")
	cat("#####################################\n")

}else{
	cat("\n")
	cat("#####################################\n")
	cat("      ERROR Nb of proteins !=  1792  \n")
	cat(dim(ratio)[1])
	cat("\n")
	cat(" 		mcq.get.ratio is KO\n")
	cat("#####################################\n")
}

if(dim(ratio)[2]==7){
	cat("\n")
	cat("#####################################\n")
	cat("      Nb of variables =  7 \n")
	cat(" 		mcq.get.ratio is OK\n")
	cat("#####################################\n")

}else{
	cat("\n")
	cat("#####################################\n")
	cat("      ERROR Nb of variables !=  7  \n")
	cat(dim(ratio)[1])
	cat("\n")
	cat(" 		mcq.get.ratio is KO\n")
	cat("#####################################\n")
}



cat ("*********************************************\n")
cat (" mcq.get.ratio OK\n")
cat ("*********************************************\n")
