library("MassChroqR")
packageVersion("MassChroqR")

cat(paste(Sys.time(),"\n",sep =""))

dir.create("/tmp/test_MassChroqR", showWarnings = FALSE)

dir.create("/tmp/test_MassChroqR/test_mcq_plot_cluster", showWarnings = FALSE)

setwd ("/tmp/test_MassChroqR/test_mcq_plot_cluster")

cat("Test mcq_plot_cluster\n")
cat ("*********************************************\n")

if (file.exists("protpep.RData")) {
	load("protpep.RData")
} else {
	protPep <- mcq.read.protpep("/gorgone/pappso/formation/Novembre2016/TD/resultats_masschroq/XIC_result_prot.tsv", "/gorgone/pappso/formation/Novembre2016/TD/resultats_masschroq/XIC_result_pep.tsv")

	# import des métadata
	metadata <- mcq.read.metadata("/gorgone/pappso/formation/Novembre2016/TD/resultats_masschroq/metadata.ods")

	# Ajout des métadata à l'objet protPep
	protPep <- mcq.merge.metadata(protPep, metadata)
	save(protPep, file="protpep.RData")
}

# test incorrect object (protPep)
result <- tryCatch({

		mcq.plot.cluster(protPep,file="cluster_protPep.pdf",flist=c("extraction","rep"))


		}, warning = function(war) {

			# warning handler picks up where error was generated
			cat(paste("MY_WARNING:  ",war))
			return()

		}, error = function(err) {

			# error handler picks up where error was generated
			cat(paste("MY_ERROR:  ",err))

			cat ("*********************************************\n")
			cat (" error message expected the class is not taken into account by mcq.plot.cluster\n")
			cat ("*********************************************\n")
			cat ("\n")

			return()

		})

if (file.exists("pkcount.RData")) {
	load("pkcount.RData")
} else {
	pkcount <- mcq.peak.counting(protPep)
	save(pkcount, file="pkcount.RData")
}
if (file.exists("pkcount.anova.RData")) {
	load("pkcount.anova.RData")
} else {
	pkcount.anova <- mcq.anova(pkcount,"extraction") 
	save(pkcount.anova, file="pkcount.anova.RData")
}

# plot pkcount.anova

result <- tryCatch({

		mcq.plot.cluster(pkcount.anova,file="cluster_pk_anova.pdf",flist=c("extraction","rep"))


		}, warning = function(war) {

			# warning handler picks up where error was generated
			cat(paste("MY_WARNING:  ",war))
			return()

		}, error = function(err) {

			# error handler picks up where error was generated
			cat(paste("MY_ERROR:  ",err))

			cat ("*********************************************\n")
			cat (" warning message expected the class is not taken into account by mcq.plot.cluster\n")
			cat ("*********************************************\n")
			cat ("\n")

			return()

		})
cat ("*********************************************\n")
cat ("plots all proteins OK \n")
cat ("*********************************************\n")
cat ("\n")

# test incorrect factor
result <- tryCatch({

		mcq.plot.cluster(pkcount.anova,file="cluster_pk.anova.pdf",flist=c("sample","rep"))


		}, warning = function(war) {

			# warning handler picks up where error was generated
			cat(paste("MY_WARNING:  ",war))
			return()

		}, error = function(err) {

			# error handler picks up where error was generated
			cat(paste("MY_ERROR:  ",err))

			cat ("*********************************************\n")
			cat (" error message expected factor is not described in your metadata\n")
			cat ("*********************************************\n")
			cat ("\n")

			return()

		})

# selection of significant proteins to limit the number of plots 
if (file.exists("pkcount.anova.signif.RData")) {
	load("pkcount.anova.signif.RData")
} else {
	pkcount.anova.signif <- mcq.select.anova.signif(pkcount.anova, pvalue=0.01,factor="extraction")
	save(pkcount.anova.signif, file="pkcount.anova.signif.RData")
}



# test incorrect nbclust
result <- tryCatch({

		mcq.plot.cluster(pkcount.anova.signif,file="cluster_pk_anova_signif.pdf",flist=c("extraction","rep"))


		}, warning = function(war) {

			# warning handler picks up where error was generated
			cat(paste("MY_WARNING:  ",war))
			return()

		}, error = function(err) {

			# error handler picks up where error was generated
			cat(paste("MY_ERROR:  ",err))

			cat ("*********************************************\n")
			cat (" error message expected the nbclust integer must be included between 1 and the number of significant proteins, (so two proteins are not enough for clustering)\n")
			cat ("*********************************************\n")
			cat ("\n")

			return()

		})
		
# Data Nov2016 only 2 proteins signif 
# http://master.bioconductor.org/help/course-materials/2002/Seattle02/Cluster/cluster.pdf 
# Sota use a divisive method : start with 1 cluster and at each step, split cluster in two parts.
# so it's impossible to have nb clust = 1

result <- tryCatch({

			mcq.plot.cluster(pkcount.anova.signif,file="cluster_pk_anova_signif.pdf",flist=c("extraction","rep"),nbclust=1)


		}, warning = function(war) {

			# warning handler picks up where error was generated
			cat(paste("MY_WARNING:  ",war))
			return()

		}, error = function(err) {

			# error handler picks up where error was generated
			cat(paste("MY_ERROR:  ",err))

			cat ("*********************************************\n")
			cat (" error message expected the nbclust integer must be included between 1 and the number of significant proteins, (so two proteins are not enough for clustering)\n")
			cat ("*********************************************\n")
			cat ("\n")

			return()

		})
		

cat ("*********************************************\n")
cat ("plots of significant proteins OK \n")
cat ("*********************************************\n")
cat ("\n")




cat ("*********************************************\n")
cat ("cluster test is OK for pkcount : see pdf in /tmp/test_MassChroqR/test_mcq_plot_cluster \n")
cat ("*********************************************\n")
