library("MassChroqR")
packageVersion("MassChroqR")

cat(paste(Sys.time(),"\n",sep =""))

dir.create("/tmp/test_MassChroqR", showWarnings = FALSE)

dir.create("/tmp/test_MassChroqR/test_mcq_select2pepbyprot", showWarnings = FALSE)

setwd ("/tmp/test_MassChroqR/test_mcq_select2pepbyprot")


cat ("*********************************************\n")
cat (" test mcq select peptides functions \n")
cat ("*********************************************\n")


if (file.exists("protpep.RData")) {
	load("protpep.RData")
} else {
	protPep <- mcq.read.protpep("/gorgone/pappso/formation/Novembre2016/TD/resultats_masschroq/XIC_result_prot.tsv", "/gorgone/pappso/formation/Novembre2016/TD/resultats_masschroq/XIC_result_pep.tsv")

	# import des métadata
	metadata <- mcq.read.metadata("/gorgone/pappso/formation/Novembre2016/TD/resultats_masschroq/metadata.ods")

	# Ajout des métadata à l'objet protPep
	protPep <- mcq.merge.metadata(protPep, metadata)
	save(protPep, file="protpep.RData")
}



cat ("summary protPep \n")
summary(protPep)
cat("\n")


# Suppression des peptides communs à plusieurs protéines
protpep.noshared <- mcq.drop.shared.peptides(protPep)

if(length(unique(protpep.noshared@proteins$protein))==1792){
	cat("\n")
	cat("#####################################\n")
	cat("      mcq.drop.shared.peptides nb prot = 1792  OK \n")
	cat("#####################################\n")

}else{
	cat("\n")
	cat("#####################################\n")
	cat("      ERROR mcq.drop.shared.peptides nb prot != 1792  \n")
	cat(length(unique(protpep.noshared@proteins$protein)))
	cat("\n")
	cat("#####################################\n")

	stop ("error")
}



cat ("summary protpep.noshared before selection 2 pep\n")
summary(protpep.noshared)
cat("\n")

# b /Si le facteur "traitement" présente moins de 3 modalités : on ne garde que les protéines quantifiées par au moins 2 peptides
protpep.noshared <- mcq.select.2pepbyprot(protpep.noshared)

cat("summary protpep.noshared after selection 2 pep\n")
summary(protpep.noshared)
cat("\n")


if(length(unique(protpep.noshared@peptides$peptide))==8454){
	cat("\n")
	cat("#####################################\n")
	cat("      mcq.select.2pepbyprot nb peptide = 8454  OK \n")
	cat("#####################################\n")

}else{
	cat("\n")
	cat("#####################################\n")
	cat("      ERROR  mcq.select.2pepbyprot nb peptide != 8454  \n")
	cat(length(unique(protpep.noshared@peptides$peptide)))
	cat("\n")
	cat("#####################################\n")

	stop ("error")
}


protpep.noshared <- mcq.select.2pepbyprot(protpep.noshared, 3)
cat("summary protpep.noshared after selection 3 pep\n")
summary(protpep.noshared)



if(length(unique(protpep.noshared@peptides$peptide))==7680){
	cat("\n")
	cat("#####################################\n")
	cat("      mcq.select.2pepbyprot 3pep nb peptide = 7680  OK \n")
	cat("#####################################\n")

}else{
	cat("\n")
	cat("#####################################\n")
	cat("      ERROR  mcq.select.2pepbyprot 3pep nb peptide != 7680  \n")
	cat(length(unique(protpep.noshared@peptides$peptide)))
	cat("\n")
	cat("#####################################\n")

	stop ("error")
}


protpep.noshared <- mcq.drop.unreproducible.peptides(protpep.noshared, method="percent", percentCutoff=0.05)
cat("summary protpep.noshared after reproducible.peptides 5%\n")
summary(protpep.noshared)



if(length(unique(protpep.noshared@peptides$peptide))==6742){
	cat("\n")
	cat("#####################################\n")
	cat("      mcq.drop.unreproducible.peptides 5% nb peptide = 6742  OK \n")
	cat("#####################################\n")

}else{
	cat("\n")
	cat("#####################################\n")
	cat("      ERROR mcq.drop.unreproducible.peptides 5% nb peptide != 6742  \n")
	cat(length(unique(protpep.noshared@peptides$peptide)))
	cat("\n")
	cat("#####################################\n")

	stop ("error")
}


protpep.noshared <- mcq.drop.unreproducible.peptides(protpep.noshared, method="percent", percentCutoff=0)
cat("summary protpep.noshared after reproducible.peptides 0%\n")
summary(protpep.noshared)



if(length(unique(protpep.noshared@peptides$peptide))==6395){
	cat("\n")
	cat("#####################################\n")
	cat("      mcq.drop.unreproducible.peptides 0% nb peptide = 6395  OK \n")
	cat("#####################################\n")

}else{
	cat("\n")
	cat("#####################################\n")
	cat("      ERROR mcq.drop.unreproducible.peptides 0% nb peptide != 6395  \n")
	cat(length(unique(protpep.noshared@peptides$peptide)))
	cat("\n")
	cat("#####################################\n")

	stop ("error")
}

#test message erreur
result <- tryCatch({

		protpep.noshared <- mcq.select.2pepbyprot(protpep.noshared, "rep")

		}, warning = function(war) {

			# warning handler picks up where error was generated
			cat(paste("MY_WARNING:  ",war))
			return()

		}, error = function(err) {

			# error handler picks up where error was generated
			cat(paste("MY_ERROR:  ",err))

			cat ("*********************************************\n")
			cat (" error message expected : the argument 'minimum.peptides.by.prot' MUST be a numeric value greater than 0\n")
			cat ("*********************************************\n")

			return()

		})


cat ("*********************************************\n")
cat (" mcq.select.2pepbyprot(protPep) OK\n")
cat ("*********************************************\n")



