
mcq.plot.peptide.reproducibility<- function (object, file=NULL) {
	if ((class(object) == "mcqProtPep") || (class(object) == "mcq.skyline")) {

		nbsample=length(unique(object@peptides$msrun))
		nbpeptiz=length(unique(object@peptides$peptiz))
		cat(paste("Number of samples : ",nbsample,"\n", sep=""))
		cat(paste("Number of peptides-modification-charge : ",nbpeptiz,"\n", sep=""))

		count=table(object@peptides$peptiz)
		nbsample=length(unique(object@peptides$msrun))
		nb.pep.rep=length(count[count==nbsample])
		names.pepz=names(count[count==nbsample])
		names.pep=unique(object@peptides$peptide[object@peptides$peptiz %in% names.pepz])
		nb.prot.rep=length(unique(object@proteins$protein[object@proteins$peptide %in% names.pep]))

		for (i in seq(0.05,1, by=0.05)){
			nb.pep.rep=c(nb.pep.rep, length(count[count>=floor(nbsample*(1-i))]))
			names.pepz=names(count[count>=floor(nbsample*(1-i))])
			names.pep=unique(object@peptides$peptide[object@peptides$peptiz %in% names.pepz])
			nb.prot.rep=c(nb.prot.rep, length(unique(object@proteins$protein[object@proteins$peptide %in% names.pep])))
		}

		if (is.null(file)){
			par(ask=FALSE)
		}
		else{
			pdf(file, title=gsub('.pdf$','',file), width=15)
		}
		par(mfrow=c(1,2))
		hist(count, main=c("Distribution of the number of samples in which", "a peptide-modif-charge was quantified"), xlab="Number of samples", nclass=nbsample, border="darkblue", ylab="Number of peptides-modif-charge")
		par(mar=c(6,4,2,5))
		plot(nb.pep.rep~seq(1,0, by=-0.05), type="b", ylab="Number of remaining peptides-modif-charge", xlab=c("Minimal proportion of samples in which", "a peptide-modif-charge must be present"), col="red")
		par(new=TRUE)
		plot(nb.prot.rep~seq(1,0, by=-0.05), axes=FALSE, xlab="", ylab="", col="blue", type="b")
		axis(4, labels=TRUE)
		mtext("Number of remaining proteins",side=4, line=2.5)
		legend("bottomleft", pch=1, col=c("red", "blue"), legend=c("Peptides-modif-charge", "Proteins"), bty="n")

		if (!is.null(file)){
			dev.off()
		}
		par(mar=c(5,4,4,2))
		par(new=FALSE)
		par(mfrow=c(1,1))
	}
	else {
		stop(paste("The class \"", class(object),"\" of the input object is not taken into account by mcq.plot.peptide.repetability",sep=""))
	}
}
