
mcq.plot.proteins = function (object,file=NULL, factor=NULL, protlist=NULL) {
	# colors definition
	cc <- c("red","green4","blue","cyan","wheat1","magenta","yellow","gray","darkorange", "brown", "purple", "yellowgreen","turquoise",  "antiquewhite2", "aquamarine",  "aquamarine4",  "chartreuse3", "chocolate" , "coral", "darkred", "darksalmon",  "darkseagreen1","darkslateblue",  "darkslategray1","darkturquoise" , "darkviolet" , "deeppink", "deeppink4", "goldenrod3", "goldenrod4","burlywood3", "lightgreen")
	palette(cc)
	dev.off()

	if (priv.mcq.is.anova.object(object)) {
		if (is.null(object@resultanov)) {
			stop("there is no anova results in your object")
		}
		if (is.null(object@paramlist$factorsignif)) {
			stop("for anova object, mcq.plot.proteins only works after mcq.select.signif")
		}
		factorName <- object@paramlist$factorsignif

		cat(paste("The factor '", factorName,"' was used to select proteins significantly different\n", sep=""))
	}
	else if (priv.mcq.is.protquant.object(object)) {
		if (is.null(factor)) {
			stop(paste("the 'factor' parameter is not defined. ", "choose one factor to display data among : ", paste(colnames(object@metadata@metadata), collapse=", "),sep=""))
		}
		if (!factor %in% colnames(object@metadata@metadata)) {
			stop(paste("the factor '",factor,"' does not exists ", " choose one factor to display data among : ", paste(colnames(object@metadata@metadata), collapse=", "),sep=""))
		}
		factorName <- factor
	} 
	else {
		stop(paste("the class '", class(object),"' is not taken into account by mcq.plot.proteins",sep=""))
	}
	if (is.null(protlist)) {
		protlist <- mcq.get.protlist(object)
	}

	if (is.null(file)){
		par(ask=TRUE)
	}
	else{
		pdf(file, title=gsub('.pdf$','',file))
	}

	tabprot <- merge(object@protval, object@metadata@metadata, by.x="msrun", by.y="row.names")
	tabprot <- merge(tabprot, object@proteins, by.x="protein", by.y="row.names")

	nbprot <- 0
	for (accession in names(protlist@proteins)) {

		tabcour <- tabprot[tabprot$accession==accession,]
		if(nrow(tabcour)==0) {

		}
		else {
			protein_name <- accession
			title <- paste(protein_name, " (", factorName, ")", sep="")

			if (dim(tabcour)[1]>0) {
				par(mar=c(5,4,0,2)+0.1)
				par(oma=c(1,1,7,1))
				boxplot(as.formula(paste("q~",factorName,sep="")), data=tabcour,col=cc)
				mtext(title,side=3, line=5.0, adj=0.5, cex=1.6,outer=TRUE)
			}
			nbprot <- nbprot +1
		}
	}
	cat(paste(nbprot, " protein(s) plotted\n", sep=""))

	if (!is.null(file)){
		dev.off()
	}

}


