\name{mcq.drop.unreproducible.peptides}

\alias{mcq.drop.unreproducible.peptides}

\title{Drop Unreproducible Peptides}

\description{This function removes from the proteomic dataset the peptides-modification-charge that considered as unreproducible because they are quantified in a too small number of samples. }

\usage{mcq.drop.unreproducible.peptides(object, method="percent", percentCutoff=0.1, flist=NULL, repFactor=NULL, repFactorCutoff=NULL, flistCutoff=NULL)}

\arguments{
	\item{object}{an object of class 'mcqProtPep' or 'mcq.skyline'}
	\item{method}{a character vector indicating the method to be used, either "percent" or "refined". See details}
	\item{percentCutoff}{a numerical value indicating the cutoff to be used in the "percent" method}
	\item{flist}{a character vector indicating the factor or the combination of factors of interest to be used in the "refined" method. See details}
	\item{repFactor}{a character vector indicating the factor corresponding to replicates in the experimental design}
	\item{repFactorCutoff}{a numerical value indicating the cutoff to be used for the factor corresponding to replicates in the "refined" method}
	\item{flistCutoff}{a numerical value indicating the cutoff to be used for the factor(s) of interest in the "refined" method}
}

\details{In the "percent" method, the peptides-modification-charge are dropped depending on the percentage of samples in which they are quantified. The peptides-modification-charge present in a proportion of samples below the percentCutoff are dropped. For example,  consider an experiment including two genotypes, two treatments and three replicates. The total number of samples is 2x2x3=12. If percentCutoff=0.3, only the peptide-modification-charge present in at least 8 samples are kept. In this method, no control is excerced on the identity of the samples in which a peptides-modification-charge is absent. Care has therefore to be taken because peptides-modification-charge that are not quantified in one or several level(s) of a factor of interest can be kept. In the previous example, a peptide-modification-charge absent in the three samples representing a particular genotype x treatement combination can be kept. In the "refined" method, the peptides-modification-charge considered as valid are those that are present in at least x replicates and in at least y levels of the factor or combination of factors of interest. Consider the previous example. We want a peptide-modification-charge to be present in at least two replicates out of three and in the four levels of the genotype x treatment combination. This means that a peptide-modification-charge has to be present in at least 2*4=8 samples. We tolerate the same proportion of missing data as in the "percent" method, but all the peptide-modification-charge that are considered for further analysis are present in all the genotype x treatment combinations.}

\value{The 'mcq.drop.unreproducible.peptides' function returns the input object without the peptides considered as unreproducible.}

\references{}

\author{}

\note{}

\seealso{'mcq.plot.peptide.reproducibility'}

\examples{

# Preliminary step: load the example dataset and merge metadata to the object of class 'mcqProtPep'
	data(extraction)
	protPep <- mcq.merge.metadata(protPep, metadata.info)
	
# Remove shared peptides
	protPep.cleaned=mcq.drop.unreproducible.peptides(protPep)
	summary(protPep)
	summary(protPep.cleaned)
}

