library("MassChroqR")
packageVersion("MassChroqR")
cat(paste(Sys.time(),"\n",sep =""))
cat("\n")

dir.create("/tmp/test_MassChroqR", showWarnings = FALSE)

dir.create("/tmp/test_MassChroqR/test_plot_protein", showWarnings = FALSE)

setwd ("/tmp/test_MassChroqR/test_plot_protein")

if (file.exists("/gorgone/pappso/data_extraction_pappso/Rdata/protpep.RData")) {
	load("/gorgone/pappso/data_extraction_pappso/Rdata/protpep.RData")
} else {
	protPep <- mcq.read.protpep("/gorgone/pappso/formation/Novembre2016/TD/resultats_masschroq/XIC_result_prot.tsv", "/gorgone/pappso/formation/Novembre2016/TD/resultats_masschroq/XIC_result_pep.tsv")

	# import metadata
	metadata <- mcq.read.metadata("/gorgone/pappso/formation/Novembre2016/TD/masschroqr/metadata.ods")

	# add metadata to the objet protPep
	protPep <- mcq.merge.metadata(protPep, metadata)
	save(protPep, file="/gorgone/pappso/data_extraction_pappso/Rdata/protpep.RData")
}

cat ("*********************************************\n")
cat("  Test mcq.plot.protein\n")
cat ("*********************************************\n")

cat ("*********************************************\n")
cat("  Test 1 : incorrect object\n")
cat ("*********************************************\n")

# test incorrect object
result <- tryCatch({

			mcq.plot.proteins(protPep)

		}, warning = function(war) {

			# warning handler picks up where error was generated
			print(paste("MY_WARNING:  ",war))
			return()

		}, error = function(err) {

			# error handler picks up where error was generated
			print(paste("MY_ERROR:  ",err))

			cat ("*********************************************\n")
			cat (" error message expected OK\n")
			cat ("*********************************************\n")

			return()

		})


#test plot proteins on peak counting 


if (file.exists("pkcount.RData")) {
	load("pkcount.RData")
} else {
	pkcount <- mcq.peak.counting(protPep)
	save(pkcount, file="pkcount.RData")
}

cat ("*********************************************\n")
cat (" Test peak counting 1 - only object in parameters\n")
cat ("*********************************************\n")

result <- tryCatch({

			mcq.plot.proteins(pkcount)

		}, warning = function(war) {

			# warning handler picks up where error was generated
			print(paste("MY_WARNING:  ",war))
			return()

		}, error = function(err) {

			# error handler picks up where error was generated
			print(paste("MY_ERROR:  ",err))

			cat ("*********************************************\n")
			cat (" error message expected OK\n")
			cat ("*********************************************\n")

			return()

		})

cat ("*********************************************\n")
cat (" Test peak counting 2 - parameters : object, protlist\n")
cat ("*********************************************\n")

plist = mcq.protlist(c("GRMZM2G139643_P01 NP_001131946 hypothetical protein LOC100193339 seq=translation; coord=4:229898346..229903473:1; parent_transcript=GRMZM2G139643_T01; parent_gene=GRMZM2G139643",
"GRMZM2G140116_P01 NP_001131498 hypothetical protein LOC100192835 seq=translation; coord=2:197230836..197232295:1; parent_transcript=GRMZM2G140116_T01; parent_gene=GRMZM2G140116"
		, "GRMZM2G004111_P01 B6TW91 Putative uncharacterized protein seq=translation; coord=8:169891088..169891851:-1; parent_transcript=GRMZM2G004111_T01; parent_gene=GRMZM2G004111"
,
"GRMZM2G001898_P01 NP_001142146 hypothetical protein LOC100274311 seq=translation; coord=7:13844415..13850805:1; parent_transcript=GRMZM2G001898_T01; parent_gene=GRMZM2G001898"
))

result <- tryCatch({

			mcq.plot.proteins(pkcount, protlist=plist)

		}, warning = function(war) {

			# warning handler picks up where error was generated
			print(paste("MY_WARNING:  ",war))
			return()

		}, error = function(err) {

			# error handler picks up where error was generated
			print(paste("MY_ERROR:  ",err))

			cat ("*********************************************\n")
			cat (" error message expected OK\n")
			cat ("*********************************************\n")

			return()

		})

cat ("*********************************************\n")
cat (" Test peak counting 3 - parameters : object, factor\n")
cat ("*********************************************\n")

	mcq.plot.proteins(pkcount, factor="extraction")
	mcq.plot.proteins(pkcount, file="plotprot_pk.pdf", factor="extraction")

cat ("*********************************************\n")
cat (paste(" protein(s) plotted must be : ",nrow(pkcount@proteins)," (= 1859)\n",sep=""))
cat ("*********************************************\n")

	
cat ("*********************************************\n")
cat (" Test peak counting 4 - parameters : object mindiff, factor\n")
cat ("*********************************************\n")


if (file.exists("pkcountmindiff.RData")) {
	load("pkcountmindiff.RData")
} else {
	pkcount.mindiff <- mcq.select.mindiff(pkcount, 2, factor="extraction")
	save(pkcount.mindiff, file="pkcountmindiff.RData")
}

	mcq.plot.proteins(pkcount.mindiff, factor="extraction")
	mcq.plot.proteins(pkcount.mindiff, file="plotprot_pk_mindiff.pdf",factor="extraction")
	
cat ("*********************************************\n")
cat (paste(" protein(s) plotted must be : ",nrow(pkcount.mindiff@proteins)," (= 110)\n",sep=""))
cat ("*********************************************\n")


cat ("*********************************************\n")
cat (" Test peak counting 5 - parameters : object mindiff+anova, factor\n")
cat ("*********************************************\n")


if (file.exists("pkcountanova.RData")) {
	load("pkcountanova.RData")
} else {
	pkcount.anova <- mcq.anova(pkcount.mindiff, "extraction")
	save(pkcount.anova, file="pkcountanova.RData")
}

result <- tryCatch({

				mcq.plot.proteins(pkcount.anova, factor="extraction")

		}, warning = function(war) {

			# warning handler picks up where error was generated
			print(paste("MY_WARNING:  ",war))
			return()

		}, error = function(err) {

			# error handler picks up where error was generated
			print(paste("MY_ERROR:  ",err))

			cat ("*********************************************\n")
			cat (" error message expected OK\n")
			cat ("*********************************************\n")

			return()

		})

cat ("*********************************************\n")
cat (" Test peak counting 6 - parameters : object mindiff+anova, factor, protlist\n")
cat ("*********************************************\n")

result <- tryCatch({

			mcq.plot.proteins(pkcount.anova, factor="extraction", protlist = plist)

		}, warning = function(war) {

			# warning handler picks up where error was generated
			print(paste("MY_WARNING:  ",war))
			return()

		}, error = function(err) {

			# error handler picks up where error was generated
			print(paste("MY_ERROR:  ",err))

			cat ("*********************************************\n")
			cat (" error message expected OK\n")
			cat ("*********************************************\n")

			return()

		})

cat ("*********************************************\n")
cat (" Test peak counting 7 - parameters : object mindiff+anova+signif, factor\n")
cat ("*********************************************\n")


if (file.exists("pkcountanovasignif.RData")) {
	load("pkcountanovasignif.RData")
} else {
	pkcount.anova.signif <- mcq.select.anova.signif(pkcount.anova, pvalue=0.05,factor="extraction")
	save(pkcount.anova.signif, file="pkcountanovasignif.RData")
}

mcq.plot.proteins(pkcount.anova.signif, file="plotprot_pk_anova_signif.pdf")

cat ("*********************************************\n")
cat (paste(" protein(s) plotted must be : ",nrow(pkcount.anova.signif@proteins)," (= 10)\n",sep=""))
cat ("*********************************************\n")


cat ("*********************************************\n")
cat ("mcq.plot.proteins test is OK for peak counting\n")
cat ("*********************************************\n")
cat ("*********************************************\n")

cat ("*********************************************\n")
cat (" Test XIC 1 - only object in parameters\n")
cat ("*********************************************\n")


if (file.exists("protq.RData")) {
	load("protq.RData")
} else {
	qprot <- mcq.protquantity(protPep)
	save(qprot, file="protq.RData")
}

result <- tryCatch({

			mcq.plot.proteins(qprot)

		}, warning = function(war) {

			# warning handler picks up where error was generated
			print(paste("MY_WARNING:  ",war))
			return()

		}, error = function(err) {

			# error handler picks up where error was generated
			print(paste("MY_ERROR:  ",err))

			cat ("*********************************************\n")
			cat (" error message expected OK\n")
			cat ("*********************************************\n")

			return()

		})


cat ("*********************************************\n")
cat (" Test XIC 2 - parameters : object, protlist\n")
cat ("*********************************************\n")
result <- tryCatch({

			mcq.plot.proteins(qprot, protlist=plist,file="plotprot_xic_plist.pdf")


		}, warning = function(war) {

			# warning handler picks up where error was generated
			print(paste("MY_WARNING:  ",war))
			return()

		}, error = function(err) {

			# error handler picks up where error was generated
			print(paste("MY_ERROR:  ",err))

			cat ("*********************************************\n")
			cat (" error message expected OK\n")
			cat ("*********************************************\n")

			return()

		})


cat ("*********************************************\n")
cat (" Test XIC 3 - parameters : object, factor\n")
cat ("*********************************************\n")

mcq.plot.proteins(qprot, factor="extraction", file="plotprot_xic.pdf")

cat ("*********************************************\n")
cat (paste(" protein(s) plotted must be : ",nrow(qprot@proteins)," (= 1859)\n",sep=""))
cat ("*********************************************\n")

cat ("*********************************************\n")
cat (" Test XIC 4 - parameters : object , factor, protlist\n")
cat ("*********************************************\n")

cat ("plot qprot for extraction with protlist=plist\n")
mcq.plot.proteins(qprot, factor="extraction", protlist=plist,file="plotprot_xic_protlist.pdf")

cat ("*********************************************\n")
cat (paste(" protein(s) plotted must be : ",length(plist@proteins)," (= 4)\n",sep=""))
cat ("*********************************************\n")


cat ("*********************************************\n")
cat (" Test XIC 5 - parameters : object anova, factor, protlist\n")
cat ("*********************************************\n")

if (file.exists("xicanova.RData")) {
	load("xicanova.RData")
} else {
	xic.anova <- mcq.anova(qprot, "extraction")
	save(xic.anova, file="xicanova.RData")
}

result <- tryCatch({

			mcq.plot.proteins(xic.anova, file="plotprot_xic_anova.pdf", factor="extraction", protlist = plist)

		}, warning = function(war) {

			# warning handler picks up where error was generated
			print(paste("MY_WARNING:  ",war))
			return()

		}, error = function(err) {

			# error handler picks up where error was generated
			print(paste("MY_ERROR:  ",err))

			cat ("*********************************************\n")
			cat (" error message expected OK\n")
			cat ("*********************************************\n")

			return()

		})

cat ("*********************************************\n")
cat (" Test XIC 6 - parameters : object anova + signif, factor\n")
cat ("*********************************************\n")

if (file.exists("xicanovasignif.RData")) {
	load("xicanovasignif.RData")
} else {
	xic.anova.signif <- mcq.select.anova.signif(xic.anova, pvalue=0.01,factor="extraction")
	save(xic.anova.signif, file="xicanovasignif.RData")
}

mcq.plot.proteins(xic.anova.signif, file="plotprot_xic_anova_signif.pdf", factor="extraction")

cat ("*********************************************\n")
cat (paste(" protein(s) plotted must be : ",nrow(xic.anova.signif@proteins)," (= 1115)\n",sep=""))
cat ("*********************************************\n")


cat ("*********************************************\n")
cat (" Test XIC 7 - parameters : object anova + signif, factor, protlist\n")
cat ("*********************************************\n")

mcq.plot.proteins(xic.anova.signif, file="plotprot_xic_anova_signif_protlist.pdf", protlist = plist)

cat ("*********************************************\n")
cat (paste(" protein(s) plotted must be : ",length(plist@proteins)," (= 4)\n",sep=""))
cat ("*********************************************\n")


cat ("*********************************************\n")
cat ("mcq.plot.proteins test is OK for XIC\n")
cat ("*********************************************\n")
cat ("*********************************************\n")



cat ("*********************************************\n")
cat ("test plot proteins on spectral counting\n")
cat ("*********************************************\n")


if (file.exists("spc.RData")) {
	load("spc.RData")
} else {
	spc <- mcq.read.spectralcounting("/gorgone/pappso/formation/Decembre2014/results_compar_spectra.txt")

	# import des métadata
	metadata <- mcq.read.metadata("/gorgone/pappso/formation/Decembre2014/metadata.ods")

	# Ajout des métadata à l'objet protPep
	spc <- mcq.merge.metadata(spc, metadata)
	save(spc, file="spc.RData")
}
cat ("*********************************************\n")
cat (" Test spectral counting 1 - only object in parameters\n")
cat ("*********************************************\n")

result <- tryCatch({

			mcq.plot.proteins(spc)

		}, warning = function(war) {

			# warning handler picks up where error was generated
			print(paste("MY_WARNING:  ",war))
			return()

		}, error = function(err) {

			# error handler picks up where error was generated
			print(paste("MY_ERROR:  ",err))

			cat ("*********************************************\n")
			cat (" error message expected OK\n")
			cat ("*********************************************\n")

			return()

		})

cat ("*********************************************\n")
cat (" Test spectral counting 2 - parameters : object, protlist\n")
cat ("*********************************************\n")

result <- tryCatch({

			mcq.plot.proteins(spc, protlist=plist)

		}, warning = function(war) {

			# warning handler picks up where error was generated
			print(paste("MY_WARNING:  ",war))
			return()

		}, error = function(err) {

			# error handler picks up where error was generated
			print(paste("MY_ERROR:  ",err))

			cat ("*********************************************\n")
			cat (" error message expected OK\n")
			cat ("*********************************************\n")

			return()

		})

cat ("*********************************************\n")
cat (" Test spectral counting 3 - parameters : object, factor\n")
cat ("*********************************************\n")

	mcq.plot.proteins(spc, factor="extraction")
	mcq.plot.proteins(spc, file='plotprot_spc.pdf', factor="extraction")
	
cat ("*********************************************\n")
cat (paste(" protein(s) plotted must be : ",nrow(spc@proteins)," (= 2061)\n",sep=""))
cat ("*********************************************\n")


cat ("*********************************************\n")
cat (" Test spectral counting 4 - parameters : object mindiff, factor\n")
cat ("*********************************************\n")

if (file.exists("spcmindiff.RData")) {
	load("spcmindiff.RData")
} else {
	spcmindiff <- mcq.select.mindiff(spc, 2, factor="extraction")
	save(spcmindiff, file="spcmindiff.RData")
}

	mcq.plot.proteins(spcmindiff, factor="extraction")
	mcq.plot.proteins(spcmindiff, file="plotprot_spc_mindiff.pdf",factor="extraction")
	
cat ("*********************************************\n")
cat (paste(" protein(s) plotted must be : ",nrow(spcmindiff@proteins)," (= 440)\n",sep=""))
cat ("*********************************************\n")


cat ("*********************************************\n")
cat (" Test spectral counting 5 - parameters : object mindiff, bad factor\n")
cat ("*********************************************\n")

result <- tryCatch({

			mcq.plot.proteins(spcmindiff, factor="mutant")
			
		}, warning = function(war) {

			# warning handler picks up where error was generated
			print(paste("MY_WARNING:  ",war))
			return()

		}, error = function(err) {

			# error handler picks up where error was generated
			print(paste("MY_ERROR:  ",err))

			cat ("*********************************************\n")
			cat (" error message expected OK\n")
			cat ("*********************************************\n")

			return()

		})


cat ("*********************************************\n")
cat (" Test spectral counting 6 - parameters : object mindiff+anova, factor\n")
cat ("*********************************************\n")

if (file.exists("spcanova.RData")) {
	load("spcanova.RData")
} else {
	spcanova <- mcq.anova(spcmindiff, "extraction")
	save(spcanova, file="spcanova.RData")
}

result <- tryCatch({

				mcq.plot.proteins(spcanova, factor="extraction")

		}, warning = function(war) {

			# warning handler picks up where error was generated
			print(paste("MY_WARNING:  ",war))
			return()

		}, error = function(err) {

			# error handler picks up where error was generated
			print(paste("MY_ERROR:  ",err))

			cat ("*********************************************\n")
			cat (" error message expected OK\n")
			cat ("*********************************************\n")

			return()

		})

cat ("*********************************************\n")
cat (" Test spectral counting 7 - parameters : object mindiff+anova+signif\n")
cat ("*********************************************\n")


if (file.exists("spcanovasignif.RData")) {
	load("spcanovasignif.RData")
} else {
	spcanovasignif <- mcq.select.anova.signif(spcanova, pvalue=0.01,factor="extraction")
	save(spcanovasignif, file="spcanovasignif.RData")
}

mcq.plot.proteins(spcanovasignif, file="plotprot_spc_anova_signif.pdf",factor="extraction")

cat ("*********************************************\n")
cat (paste(" protein(s) plotted must be : ",nrow(spcanovasignif@proteins)," (= 80)\n",sep=""))
cat ("*********************************************\n")


cat ("*********************************************\n")
cat ("mcq.plot.proteins test is OK for spectral counting\n")
cat ("*********************************************\n")



